rm(list=ls())
library(lmeresampler)
library(nlmeU)
library(lme4);library(lmerTest)
library(nlme);library(piecewiseSEM)
library(boot);library(Rfit);library(MCMCglmm)
library(MuMIn);library(ggplot2)
library(reshape2);library(ggsci)
library(grid);library(gridExtra)
library(gtable);library(plyr)
library(dplyr);library(data.table)
library(MuMIn);options(na.action = "na.fail")
library(glmnet);library(glmnetUtils)
library(SoDA);library(spdep);library(spaMM)
library(randomForest);library(fastDummies)

can<-fread("Hisano_GCB.csv")

can[,":="(PS=scale(PS1))] %>% 
  .[,":="(Y=scale(FinY),
          SA=scale(FinSA),
          logSA1=log(FinSA),
          sqrtSA1=sqrt(FinSA),
          CMIave=scale(CMIave1),
          MATave=scale(MATave1))] %>% 
  .[,":="(quadSA=(SA^2),
          CO2=scale(CO21),
          ATA=scale(ATA1),
          ACMIA=scale(ACMIA1),
          ATAChangeRate=scale(ATAChangeRate1),
          ACMIAChangeRate=scale(ACMIAChangeRate1),
          logSA=scale(logSA1),
          sqrtSA=scale(sqrtSA1))] %>% 
  .[,":="(MEM1=scale(MEM1),
          MEM2=scale(MEM2),
          MEM3=scale(MEM3),
          MEM4=scale(MEM4),
          MEM5=scale(MEM5),
          MEM6=scale(MEM6),
          MEM7=scale(MEM7),
          MEM8=scale(MEM8),
          MEM9=scale(MEM9),
          MEM10=scale(MEM10),
          MEM11=scale(MEM11),
          MEM12=scale(MEM12),
          MEM13=scale(MEM13),
          MEM14=scale(MEM14),
          MEM15=scale(MEM15),
          MEM16=scale(MEM16),
          MEM17=scale(MEM17),
          MEM18=scale(MEM18),
          MEM19=scale(MEM19),
          MEM20=scale(MEM20),
          MEM21=scale(MEM21),
          MEM22=scale(MEM22),
          MEM23=scale(MEM23),
          MEM24=scale(MEM24))]

#### Fig. 1 is not shown to protect the Permanent Sample Plot (PSP) information based on the data sharing agreement ####

#### Fig. 2 is not shown to protect the plant trait (TRY) information based on the data sharing agreement ####

#### Fig. 3 ####
#https://stat.ethz.ch/pipermail/r-sig-mixed-models/2017q4/026107.html
nsamp <- 1000
THIN <- 50
BURNIN <- 3000
NITT <- BURNIN + THIN*nsamp

#PC1 Model
m1_mcmc<-MCMCglmm(PC1~PS+Prov+
                    MEM3+MEM5+MEM6+MEM7+MEM8+MEM9+MEM12+MEM13+MEM15+MEM16+MEM20+
                    sqrtSA+Y+CMIave+MATave+
                    sqrtSA:Y+sqrtSA:CMIave+sqrtSA:MATave+Y:CMIave+Y:MATave+CMIave:MATave,
                  random = ~PLOT_ID, 
                  data = can,
                  nitt = NITT, thin = THIN, burnin = BURNIN)

#save(m1_mcmc,file="m1_mcmc_th50_it53K.R")
load("m1_mcmc_th50_it53K.R")

plot(m1_mcmc$Sol[,"(Intercept)"])
plot(m1_mcmc$Sol[,"Y:MATave"])

summary(m1_mcmc$Sol)

summary(m1_mcmc)$solutions

#an autocorrelation less than 0.1 for the first Lag
autocorr.diag(m1_mcmc$Sol[,c(1:2,23:32)])
autocorr.diag(m1_mcmc$Sol)

effectiveSize(m1_mcmc$Sol)
effectiveSize(m1_mcmc$VCV)

#PC2 Model
m2_mcmc<-MCMCglmm(PC2~PS+Prov+
                    MEM3+MEM4+MEM5+MEM6+MEM9+MEM15+MEM20+MEM22+MEM23+
                    sqrtSA+Y+CMIave+MATave+
                    sqrtSA:Y+sqrtSA:CMIave+sqrtSA:MATave+Y:CMIave+Y:MATave+CMIave:MATave,
                  random = ~PLOT_ID, 
                  data = can,
                  nitt = NITT, thin = THIN, burnin = BURNIN)

#save(m2_mcmc,file="m2_mcmc_th50_it53K.R")
load("m2_mcmc_th50_it53K.R")

plot(m2_mcmc$Sol[,"(Intercept)"])
plot(m2_mcmc$Sol[,"Y:MATave"])

summary(m2_mcmc$Sol)

summary(m2_mcmc)$solutions

#an autocorrelation less than 0.1 for the first Lag
autocorr.diag(m2_mcmc$Sol)

effectiveSize(m2_mcmc$Sol)
effectiveSize(m2_mcmc$VCV)

library(lattice)
xyplot(as.mcmc(m1_mcmc$Sol))
densityplot(m1_mcmc$Sol)

summary(m1_mcmc$Sol)

summary(m1_mcmc)$so

#### PC1 Graph ####
PC1_T<-data.table(Source=c("Intercept","PS","f(SA)","Year","CMIave","MATave",
                           "f(SA):Year","f(SA):CMIave","f(SA):MATave","Year:CMIave",
                           "Year:MATave","CMIave:MATave"),
                  mean.PC1=NA,up.PC1=NA,low.PC1=NA)

PC1_T$mean.PC1<-summary(m1_mcmc)$sol[c("(Intercept)","PS","sqrtSA","Y","CMIave","MATave",
                                       "sqrtSA:Y","sqrtSA:CMIave","sqrtSA:MATave","Y:CMIave",
                                       "Y:MATave","CMIave:MATave"),1]

PC1_T$up.PC1<-summary(m1_mcmc)$sol[c("(Intercept)","PS","sqrtSA","Y","CMIave","MATave",
                                     "sqrtSA:Y","sqrtSA:CMIave","sqrtSA:MATave","Y:CMIave",
                                     "Y:MATave","CMIave:MATave"),3]

PC1_T$low.PC1<-summary(m1_mcmc)$sol[c("(Intercept)","PS","sqrtSA","Y","CMIave","MATave",
                                      "sqrtSA:Y","sqrtSA:CMIave","sqrtSA:MATave","Y:CMIave",
                                      "Y:MATave","CMIave:MATave"),2]


PC1_T$Source<-factor(PC1_T$Source,levels=rev(c("Intercept","PS","f(SA)","Year","CMIave","MATave",
                                               "f(SA):Year","f(SA):CMIave","f(SA):MATave","Year:CMIave",
                                               "Year:MATave","CMIave:MATave")))

PC1<-ggplot(PC1_T[Source!="Intercept"],aes(x=mean.PC1,xmin=low.PC1,xmax=up.PC1,y=Source))+
  geom_vline(aes(xintercept=0),linetype="dashed",colour="grey")+ 
  geom_point(position=position_dodge(0.4),col="royalblue")+
  geom_errorbar(position=position_dodge(0.4),width=0.2,col="royalblue")+
  scale_color_discrete(name="Model")+
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank())+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  xlab(expression(paste("Coefficient estimate")))+ylab("")
PC1

#### PC2 Graph ####
PC2_T<-data.table(Source=c("Intercept","PS","f(SA)","Year","CMIave","MATave",
                           "f(SA):Year","f(SA):CMIave","f(SA):MATave","Year:CMIave",
                           "Year:MATave","CMIave:MATave"),
                  mean.PC2=NA,up.PC2=NA,low.PC2=NA)

PC2_T$mean.PC2<-summary(m2_mcmc)$sol[c("(Intercept)","PS","sqrtSA","Y","CMIave","MATave",
                                       "sqrtSA:Y","sqrtSA:CMIave","sqrtSA:MATave","Y:CMIave",
                                       "Y:MATave","CMIave:MATave"),1]

PC2_T$up.PC2<-summary(m2_mcmc)$sol[c("(Intercept)","PS","sqrtSA","Y","CMIave","MATave",
                                     "sqrtSA:Y","sqrtSA:CMIave","sqrtSA:MATave","Y:CMIave",
                                     "Y:MATave","CMIave:MATave"),3]

PC2_T$low.PC2<-summary(m2_mcmc)$sol[c("(Intercept)","PS","sqrtSA","Y","CMIave","MATave",
                                      "sqrtSA:Y","sqrtSA:CMIave","sqrtSA:MATave","Y:CMIave",
                                      "Y:MATave","CMIave:MATave"),2]


PC2_T$Source<-factor(PC2_T$Source,levels=rev(c("Intercept","PS","f(SA)","Year","CMIave","MATave",
                                               "f(SA):Year","f(SA):CMIave","f(SA):MATave","Year:CMIave",
                                               "Year:MATave","CMIave:MATave")))

PC2<-ggplot(PC2_T[Source!="Intercept"],aes(x=mean.PC2,xmin=low.PC2,xmax=up.PC2,y=Source))+
  geom_vline(aes(xintercept=0),linetype="dashed",colour="grey")+ 
  geom_point(position=position_dodge(0.4),col="maroon")+
  geom_errorbar(position=position_dodge(0.4),width=0.2,col="maroon")+
  scale_color_discrete(name="Model")+
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank())+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  xlab(expression(paste("Coefficient estimate")))+ylab("")
PC2

#### Bind ####
maxWidth = unit.pmax(PC1$widths[2:3],PC2$widths[2:3])
PC1$widths[2:3] <- maxWidth
PC2$widths[2:3] <- maxWidth

p1<-ggplot_gtable(ggplot_build(PC1))
p2<-ggplot_gtable(ggplot_build(PC2))

tiff("Fig3_MCMCglmm_Effect_Size.tiff",width=3000,height=2000,res=300,compression="lzw")
grid.draw(cbind(p1,p2,size="last"))
grid.text(expression(paste("a (",CWM[PC1],")")),x=unit(0.19,"npc"),y=unit(0.96,"npc"),gp=gpar(fontsize=12,font=2))
grid.text(expression(paste("b (",CWM[PC2],")")),x=unit(0.69,"npc"),y=unit(0.96,"npc"),gp=gpar(fontsize=12,font=2))

dev.off()

#### Fig. 4 ####
#### PC1 ####
#### Main Effects (except for covariates) ####
coefmean<-summary(m1_mcmc)$sol[,1]
coefmean_Int<-mean(c(coefmean["(Intercept)"],
                     coefmean["(Intercept)"]+coefmean["ProvAC"],
                     coefmean["(Intercept)"]+coefmean["ProvBC"],
                     coefmean["(Intercept)"]+coefmean["ProvMB"],
                     coefmean["(Intercept)"]+coefmean["ProvNFImm"],
                     coefmean["(Intercept)"]+coefmean["ProvNFMat"],
                     coefmean["(Intercept)"]+coefmean["ProvNS"],
                     coefmean["(Intercept)"]+coefmean["ProvON"],
                     coefmean["(Intercept)"]+coefmean["ProvQC"],
                     coefmean["(Intercept)"]+coefmean["ProvSK"]))

coefCIlow<-summary(m1_mcmc)$sol[,2]
coefCIlow_Int<-mean(c(coefCIlow["(Intercept)"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvAC"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvBC"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvMB"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvNFImm"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvNFMat"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvNS"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvON"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvQC"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvSK"]))

coefCIup<-summary(m1_mcmc)$sol[,3]
coefCIup_Int<-mean(c(coefCIup["(Intercept)"],
                     coefCIup["(Intercept)"]+coefCIup["ProvAC"],
                     coefCIup["(Intercept)"]+coefCIup["ProvBC"],
                     coefCIup["(Intercept)"]+coefCIup["ProvMB"],
                     coefCIup["(Intercept)"]+coefCIup["ProvNFImm"],
                     coefCIup["(Intercept)"]+coefCIup["ProvNFMat"],
                     coefCIup["(Intercept)"]+coefCIup["ProvNS"],
                     coefCIup["(Intercept)"]+coefCIup["ProvON"],
                     coefCIup["(Intercept)"]+coefCIup["ProvQC"],
                     coefCIup["(Intercept)"]+coefCIup["ProvSK"]))

can$PC1_resid<-can$PC1-predict(m1_mcmc)

#### SA ####
can$PC1_sqrtSA<-can$PC1_resid+coefmean_Int+coefmean["sqrtSA"]*can$sqrtSA

to_graph<-data.table(mean=coefmean_Int+(coefmean["sqrtSA"]*(seq(min(can$sqrtSA),max(can$sqrtSA),length=600))),
                     up=coefCIup_Int+(coefCIup["sqrtSA"]*(seq(min(can$sqrtSA),max(can$sqrtSA),length=600))),
                     low=coefCIlow_Int+(coefCIlow["sqrtSA"]*(seq(min(can$sqrtSA),max(can$sqrtSA),length=600))),
                     sqrtSA=seq(min(can$sqrtSA),max(can$sqrtSA),length=600),
                     sqrtSA1=(seq(min(can$sqrtSA1),max(can$sqrtSA1),length=600)))

G1sqrtSA<-ggplot()+
  stat_summary_bin(data=can,aes(x=(sqrtSA1)^2, y=PC1_sqrtSA),fun.data = "mean_cl_boot",
                   colour = "lightblue", shape=1, bins=3000)+
  geom_ribbon(aes(x=(to_graph$sqrtSA1)^2,ymin=to_graph$low,
                  ymax=to_graph$up), fill="royalblue", alpha=0.4)+
  geom_line(aes(x=(to_graph$sqrtSA1)^2,y=to_graph$mean),colour="navy",size=0.4)+
  theme(axis.line.x = element_blank(),axis.ticks.x=element_blank(),axis.text.x=element_blank(),
        axis.line.y = element_line(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())+
  ylab(expression(paste("Conifers    (",CWM[PC1],")    DB")))+
  xlab(expression(paste("")))+
  ylim(c(-5,5))+
  xlim(c(quantile((can$sqrtSA1)^2,0.01)[[1]],quantile((can$sqrtSA1)^2,0.99)[[1]]))

g1 <- ggplotGrob(G1sqrtSA)

#### CMIave ####
can$PC1_CMIave<-can$PC1_resid+coefmean_Int+coefmean["CMIave"]*can$CMIave

to_graph<-data.table(mean=coefmean_Int+(coefmean["CMIave"]*(seq(min(can$CMIave),max(can$CMIave),length=600))),
                     up=coefCIup_Int+(coefCIup["CMIave"]*(seq(min(can$CMIave),max(can$CMIave),length=600))),
                     low=coefCIlow_Int+(coefCIlow["CMIave"]*(seq(min(can$CMIave),max(can$CMIave),length=600))),
                     CMIave=seq(min(can$CMIave),max(can$CMIave),length=600),
                     CMIave1=(seq(min(can$CMIave1),max(can$CMIave1),length=600)))

G2CMIave<-ggplot()+
  stat_summary_bin(data=can,aes(x=CMIave1, y=PC1_CMIave),fun.data = "mean_cl_boot",
                   colour = "lightblue", shape=1, bins=3000)+
  geom_ribbon(aes(x=to_graph$CMIave1,ymin=to_graph$low,
                  ymax=to_graph$up), fill="royalblue", alpha=0.4)+
  geom_line(aes(x=to_graph$CMIave1,y=to_graph$mean),colour="navy",size=0.4)+
  theme(axis.line.x = element_blank(),axis.ticks.x=element_blank(),axis.text.x=element_blank(),
        axis.line.y = element_line(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())+
  ylab(expression(paste("Conifers    (",CWM[PC1],")    DB")))+
  xlab(expression(paste("")))+
  ylim(c(-5,5))+
  xlim(c(quantile(can$CMIave1,0.01)[[1]],quantile(can$CMIave1,0.99)[[1]]))

g2 <- ggplotGrob(G2CMIave)

#### MATave ####
can$PC1_MATave<-can$PC1_resid+coefmean_Int+coefmean["MATave"]*can$MATave

to_graph<-data.table(mean=coefmean_Int+(coefmean["MATave"]*(seq(min(can$MATave),max(can$MATave),length=600))),
                     up=coefCIup_Int+(coefCIup["MATave"]*(seq(min(can$MATave),max(can$MATave),length=600))),
                     low=coefCIlow_Int+(coefCIlow["MATave"]*(seq(min(can$MATave),max(can$MATave),length=600))),
                     MATave=seq(min(can$MATave),max(can$MATave),length=600),
                     MATave1=(seq(min(can$MATave1),max(can$MATave1),length=600)))

G3MATave<-ggplot()+
  stat_summary_bin(data=can,aes(x=MATave1, y=PC1_MATave),fun.data = "mean_cl_boot",
                   colour = "lightblue", shape=1, bins=3000)+
  geom_ribbon(aes(x=to_graph$MATave1,ymin=to_graph$low,
                  ymax=to_graph$up), fill="royalblue", alpha=0.4)+
  geom_line(aes(x=to_graph$MATave1,y=to_graph$mean),colour="navy",size=0.4)+
  theme(axis.line.x = element_blank(),axis.ticks.x=element_blank(),axis.text.x=element_blank(),
        axis.line.y = element_line(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())+
  ylab(expression(paste("Conifers    (",CWM[PC1],")    DB")))+
  xlab(expression(paste("")))+
  ylim(c(-5,5))+
  xlim(c(quantile(can$MATave1,0.01)[[1]],quantile(can$MATave1,0.99)[[1]]))

g3 <- ggplotGrob(G3MATave)

#### PC2 ####
#### Main Effects (except for covariates) ####
coefmean<-summary(m2_mcmc)$sol[,1]
coefmean_Int<-mean(c(coefmean["(Intercept)"],
                     coefmean["(Intercept)"]+coefmean["ProvAC"],
                     coefmean["(Intercept)"]+coefmean["ProvBC"],
                     coefmean["(Intercept)"]+coefmean["ProvMB"],
                     coefmean["(Intercept)"]+coefmean["ProvNFImm"],
                     coefmean["(Intercept)"]+coefmean["ProvNFMat"],
                     coefmean["(Intercept)"]+coefmean["ProvNS"],
                     coefmean["(Intercept)"]+coefmean["ProvON"],
                     coefmean["(Intercept)"]+coefmean["ProvQC"],
                     coefmean["(Intercept)"]+coefmean["ProvSK"]))

coefCIlow<-summary(m2_mcmc)$sol[,2]
coefCIlow_Int<-mean(c(coefCIlow["(Intercept)"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvAC"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvBC"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvMB"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvNFImm"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvNFMat"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvNS"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvON"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvQC"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvSK"]))

coefCIup<-summary(m2_mcmc)$sol[,3]
coefCIup_Int<-mean(c(coefCIup["(Intercept)"],
                     coefCIup["(Intercept)"]+coefCIup["ProvAC"],
                     coefCIup["(Intercept)"]+coefCIup["ProvBC"],
                     coefCIup["(Intercept)"]+coefCIup["ProvMB"],
                     coefCIup["(Intercept)"]+coefCIup["ProvNFImm"],
                     coefCIup["(Intercept)"]+coefCIup["ProvNFMat"],
                     coefCIup["(Intercept)"]+coefCIup["ProvNS"],
                     coefCIup["(Intercept)"]+coefCIup["ProvON"],
                     coefCIup["(Intercept)"]+coefCIup["ProvQC"],
                     coefCIup["(Intercept)"]+coefCIup["ProvSK"]))

can$PC2_resid<-can$PC2-predict(m2_mcmc)

#### SA ####
can$PC2_sqrtSA<-can$PC2_resid+coefmean_Int+coefmean["sqrtSA"]*can$sqrtSA

to_graph<-data.table(mean=coefmean_Int+(coefmean["sqrtSA"]*(seq(min(can$sqrtSA),max(can$sqrtSA),length=600))),
                     up=coefCIup_Int+(coefCIup["sqrtSA"]*(seq(min(can$sqrtSA),max(can$sqrtSA),length=600))),
                     low=coefCIlow_Int+(coefCIlow["sqrtSA"]*(seq(min(can$sqrtSA),max(can$sqrtSA),length=600))),
                     sqrtSA=seq(min(can$sqrtSA),max(can$sqrtSA),length=600),
                     sqrtSA1=(seq(min(can$sqrtSA1),max(can$sqrtSA1),length=600)))

G4sqrtSA<-ggplot()+
  stat_summary_bin(data=can,aes(x=(sqrtSA1)^2, y=PC2_sqrtSA),fun.data = "mean_cl_boot",
                   colour = "lightblue", shape=1, bins=3000)+
  geom_ribbon(aes(x=(to_graph$sqrtSA1)^2,ymin=to_graph$low,
                  ymax=to_graph$up), fill="royalblue", alpha=0.4)+
  geom_line(aes(x=(to_graph$sqrtSA1)^2,y=to_graph$mean),colour="navy",size=0.4)+
  theme(axis.line.x = element_line(),axis.line.y = element_line(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())+
  ylab(expression(paste("Lower DT    ","(CW",M[PC2],")    Higher DT")))+
  xlab(expression(paste("Stand age (years)")))+
  ylim(c(-5,5))+
  xlim(c(quantile((can$sqrtSA1)^2,0.01)[[1]],quantile((can$sqrtSA1)^2,0.99)[[1]]))


h1 <- ggplotGrob(G4sqrtSA)

#### CMIave ####
can$PC2_CMIave<-can$PC2_resid+coefmean_Int+coefmean["CMIave"]*can$CMIave

to_graph<-data.table(mean=coefmean_Int+(coefmean["CMIave"]*(seq(min(can$CMIave),max(can$CMIave),length=600))),
                     up=coefCIup_Int+(coefCIup["CMIave"]*(seq(min(can$CMIave),max(can$CMIave),length=600))),
                     low=coefCIlow_Int+(coefCIlow["CMIave"]*(seq(min(can$CMIave),max(can$CMIave),length=600))),
                     CMIave=seq(min(can$CMIave),max(can$CMIave),length=600),
                     CMIave1=(seq(min(can$CMIave1),max(can$CMIave1),length=600)))

G5CMIave<-ggplot()+
  stat_summary_bin(data=can,aes(x=CMIave1, y=PC2_CMIave),fun.data = "mean_cl_boot",
                   colour = "lightblue", shape=1, bins=3000)+
  geom_ribbon(aes(x=to_graph$CMIave1,ymin=to_graph$low,
                  ymax=to_graph$up), fill="royalblue", alpha=0.4)+
  geom_line(aes(x=to_graph$CMIave1,y=to_graph$mean),colour="navy",size=0.4)+
  theme(axis.line.x = element_line(),axis.line.y = element_line(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())+
  ylab(expression(paste("Lower DT    ","(CW",M[PC2],")    Higher DT")))+
  xlab(expression(paste(CMI[ave]," (cm)")))+
  ylim(c(-5,5))+
  xlim(c(quantile(can$CMIave1,0.01)[[1]],quantile(can$CMIave1,0.99)[[1]]))

h2 <- ggplotGrob(G5CMIave)

#### MATave ####
can$PC2_MATave<-can$PC2_resid+coefmean_Int+coefmean["MATave"]*can$MATave

to_graph<-data.table(mean=coefmean_Int+(coefmean["MATave"]*(seq(min(can$MATave),max(can$MATave),length=600))),
                     up=coefCIup_Int+(coefCIup["MATave"]*(seq(min(can$MATave),max(can$MATave),length=600))),
                     low=coefCIlow_Int+(coefCIlow["MATave"]*(seq(min(can$MATave),max(can$MATave),length=600))),
                     MATave=seq(min(can$MATave),max(can$MATave),length=600),
                     MATave1=(seq(min(can$MATave1),max(can$MATave1),length=600)))

G6MATave<-ggplot()+
  stat_summary_bin(data=can,aes(x=MATave1, y=PC2_MATave),fun.data = "mean_cl_boot",
                   colour = "lightblue", shape=1, bins=3000)+
  geom_ribbon(aes(x=to_graph$MATave1,ymin=to_graph$low,
                  ymax=to_graph$up), fill="royalblue", alpha=0.4)+
  geom_line(aes(x=to_graph$MATave1,y=to_graph$mean),colour="navy",size=0.4)+
  theme(axis.line.x = element_line(),axis.line.y = element_line(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())+
  ylab(expression(paste("Lower DT    ","(CW",M[PC2],")    Higher DT")))+
  xlab(expression(paste(MAT[ave]," (",~degree*C,")")))+
  ylim(c(-5,5))+
  xlim(c(quantile(can$MATave1,0.01)[[1]],quantile(can$MATave1,0.99)[[1]]))

h3 <- ggplotGrob(G6MATave)

#### Bind figures ####
rbind_gtable_max <- function(...){
  gtl <- list(...)
  stopifnot(all(sapply(gtl, is.gtable)))
  bind2 <- function (x, y) 
  {
    stopifnot(ncol(x) == ncol(y))
    if (nrow(x) == 0) 
      return(y)
    if (nrow(y) == 0) 
      return(x)
    y$layout$t <- y$layout$t + nrow(x)
    y$layout$b <- y$layout$b + nrow(x)
    x$layout <- rbind(x$layout, y$layout)
    x$heights <- gtable:::insert.unit(x$heights, y$heights)
    x$rownames <- c(x$rownames, y$rownames)
    x$widths <- grid::unit.pmax(x$widths, y$widths)
    x$grobs <- append(x$grobs, y$grobs)
    x
  }
  
  Reduce(bind2, gtl)
}

maxWidth = unit.pmax(g1$widths[2:3], g2$widths[2:3], g3$widths[2:3])
g1$widths[2:3] <- maxWidth
g2$widths[2:3] <- maxWidth
g3$widths[2:3] <- maxWidth

maxWidth = unit.pmax(h1$widths[2:3], h2$widths[2:3], h3$widths[2:3])
h1$widths[2:3] <- maxWidth
h2$widths[2:3] <- maxWidth
h3$widths[2:3] <- maxWidth

tiff("Fig4_MCMCglmm_Main_Effects_SA_CMIave_MATave.tiff",width=3700,height=2700,res=300,compression="lzw")
grid.draw(cbind(rbind(g1,h1,size="last"),rbind(g2,h2,size="last"),rbind(g3,h3,size="last"),size="first"))
grid.text("a",x=unit(0.01,"npc"),y=unit(0.98,"npc"),gp=gpar(fontsize=14,font=2))
grid.text("b",x=unit(0.344,"npc"),y=unit(0.98,"npc"),gp=gpar(fontsize=14,font=2))
grid.text("c",x=unit(0.676,"npc"),y=unit(0.98,"npc"),gp=gpar(fontsize=14,font=2))

dev.off()

#### Fig. 5 ####
load("m1_mcmc_th50_it53K.R")
load("m2_mcmc_th50_it53K.R")

#### PC1 ####
coefmean<-summary(m1_mcmc)$sol[,1]
coefmean_Int<-mean(c(coefmean["(Intercept)"],
                     coefmean["(Intercept)"]+coefmean["ProvAC"],
                     coefmean["(Intercept)"]+coefmean["ProvBC"],
                     coefmean["(Intercept)"]+coefmean["ProvMB"],
                     coefmean["(Intercept)"]+coefmean["ProvNFImm"],
                     coefmean["(Intercept)"]+coefmean["ProvNFMat"],
                     coefmean["(Intercept)"]+coefmean["ProvNS"],
                     coefmean["(Intercept)"]+coefmean["ProvON"],
                     coefmean["(Intercept)"]+coefmean["ProvQC"],
                     coefmean["(Intercept)"]+coefmean["ProvSK"]))

coefCIlow<-summary(m1_mcmc)$sol[,2]
coefCIlow_Int<-mean(c(coefCIlow["(Intercept)"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvAC"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvBC"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvMB"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvNFImm"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvNFMat"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvNS"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvON"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvQC"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvSK"]))

coefCIup<-summary(m1_mcmc)$sol[,3]
coefCIup_Int<-mean(c(coefCIup["(Intercept)"],
                     coefCIup["(Intercept)"]+coefCIup["ProvAC"],
                     coefCIup["(Intercept)"]+coefCIup["ProvBC"],
                     coefCIup["(Intercept)"]+coefCIup["ProvMB"],
                     coefCIup["(Intercept)"]+coefCIup["ProvNFImm"],
                     coefCIup["(Intercept)"]+coefCIup["ProvNFMat"],
                     coefCIup["(Intercept)"]+coefCIup["ProvNS"],
                     coefCIup["(Intercept)"]+coefCIup["ProvON"],
                     coefCIup["(Intercept)"]+coefCIup["ProvQC"],
                     coefCIup["(Intercept)"]+coefCIup["ProvSK"]))

#### CMIave ####
coef_CMIave<-function(x){
  CMIave=x
  data.table(mean=coefmean_Int+(coefmean["Y"]*(seq(min(can$Y),max(can$Y),length=600)))+(coefmean["CMIave"]*CMIave)+
               (coefmean["Y:CMIave"]*CMIave*(seq(min(can$Y),max(can$Y),length=600))),
             up=sapply(seq(min(can$Y),max(can$Y),length=600),function(x,r=CMIave){
               coefCIup_Int+(coefCIup["Y"]*x)+(coefCIup["CMIave"]*r)+(coefCIup["Y:CMIave"]*x*r)}),
             low=sapply(seq(min(can$Y),max(can$Y),length=600),function(x,r=CMIave){
               coefCIlow_Int+(coefCIlow["Y"]*x)+(coefCIlow["CMIave"]*r)+(coefCIlow["Y:CMIave"]*x*r)}),
             Y=seq(min(can$Y),max(can$Y),length=600),
             FinY=(seq(min(can$Y),max(can$Y),length=600))*sd(can$FinY)+mean(can$FinY),
             CMIaverage=CMIave)
}

to_graph<-adply(round(c(seq(quantile(can$CMIave,0.05),quantile(can$CMIave,0.95),length=4),0),2),
                .margins=1,.fun=function(x)coef_CMIave(x))
to_graph$CMIaverage<-as.factor(to_graph$CMIaverage)

round(c(seq(quantile(can$CMIave1,0.05),quantile(can$CMIave1,0.95),length=4),mean(can$CMIave1)),1)

PC1_CMIave<-ggplot(to_graph,aes(x=FinY,y=mean,col=CMIaverage,linetype=CMIaverage))+
  theme_classic()+
  geom_ribbon(aes(x=FinY,ymin=low,ymax=up,group=CMIaverage),fill="royalblue",col=NA,alpha=0.05)+
  geom_line(size=1.1)+
  scale_linetype_manual(values = c("solid","solid","solid","solid","solid"),guide=F)+
  scale_colour_manual(values=c("lightskyblue1","skyblue2","black","royalblue1","royalblue4"),
                      name=expression(paste(CMI[ave]," (cm)")),
                      labels=c("-1.39"="1.0", "-0.53"="35.6","0.33"="70.2","1.2"="104.8","0"="Mean (56.8)"))+
  xlab("")+
  ylab(expression(paste("Conifers    (",CWM[PC1],")    DB")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x=element_blank(), axis.line.y = element_line())+
  ylim(c(-2.6,1.0))
PC1_CMIave

j1 <- ggplotGrob(PC1_CMIave)

#### MATave ####
coef_MATave<-function(x){
  MATave=x
  data.table(mean=coefmean_Int+(coefmean["Y"]*(seq(min(can$Y),max(can$Y),length=600)))+(coefmean["MATave"]*MATave)+
               (coefmean["Y:MATave"]*MATave*(seq(min(can$Y),max(can$Y),length=600))),
             up=sapply(seq(min(can$Y),max(can$Y),length=600),function(x,r=MATave){
               coefCIup_Int+(coefCIup["Y"]*x)+(coefCIup["MATave"]*r)+(coefCIup["Y:MATave"]*x*r)}),
             low=sapply(seq(min(can$Y),max(can$Y),length=600),function(x,r=MATave){
               coefCIlow_Int+(coefCIlow["Y"]*x)+(coefCIlow["MATave"]*r)+(coefCIlow["Y:MATave"]*x*r)}),
             Y=seq(min(can$Y),max(can$Y),length=600),
             FinY=(seq(min(can$Y),max(can$Y),length=600))*sd(can$FinY)+mean(can$FinY),
             MATaverage=MATave)
}

to_graph<-adply(round(c(seq(quantile(can$MATave,0.05),quantile(can$MATave,0.95),length=4),0),2),
                .margins=1,.fun=function(x)coef_MATave(x))
to_graph$MATaverage<-as.factor(to_graph$MATaverage)

round(c(seq(quantile(can$MATave1,0.05),quantile(can$MATave1,0.95),length=4),mean(can$MATave1)),1)

PC1_MATave<-ggplot(to_graph,aes(x=FinY,y=mean,col=MATaverage,linetype=MATaverage))+
  theme_classic()+
  geom_ribbon(aes(x=FinY,ymin=low,ymax=up,group=MATaverage),fill="royalblue",col=NA,alpha=0.05)+
  geom_line(size=1.1)+
  scale_linetype_manual(values = c("solid","solid","solid","solid","solid"),guide=F)+
  scale_colour_manual(values=c("steelblue","olivedrab","black","goldenrod3","hotpink3"),
                      name=expression(paste(MAT[ave]," (",~degree*C,")")),
                      labels=c("-1.63"="-1.6", "-0.55"="1.3","0.53"="4.2","1.61"="7.1","0"="Mean (2.8)"))+
  xlab("")+
  ylab(expression(paste("Conifers    (",CWM[PC1],")    DB")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line())#+
#ylim(c(-3.2,1.5))
PC1_MATave

k1 <- ggplotGrob(PC1_MATave)

#### PC2 ####
coefmean<-summary(m2_mcmc)$sol[,1]
coefmean_Int<-mean(c(coefmean["(Intercept)"],
                     coefmean["(Intercept)"]+coefmean["ProvAC"],
                     coefmean["(Intercept)"]+coefmean["ProvBC"],
                     coefmean["(Intercept)"]+coefmean["ProvMB"],
                     coefmean["(Intercept)"]+coefmean["ProvNFImm"],
                     coefmean["(Intercept)"]+coefmean["ProvNFMat"],
                     coefmean["(Intercept)"]+coefmean["ProvNS"],
                     coefmean["(Intercept)"]+coefmean["ProvON"],
                     coefmean["(Intercept)"]+coefmean["ProvQC"],
                     coefmean["(Intercept)"]+coefmean["ProvSK"]))

coefCIlow<-summary(m2_mcmc)$sol[,2]
coefCIlow_Int<-mean(c(coefCIlow["(Intercept)"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvAC"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvBC"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvMB"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvNFImm"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvNFMat"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvNS"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvON"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvQC"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvSK"]))

coefCIup<-summary(m2_mcmc)$sol[,3]
coefCIup_Int<-mean(c(coefCIup["(Intercept)"],
                     coefCIup["(Intercept)"]+coefCIup["ProvAC"],
                     coefCIup["(Intercept)"]+coefCIup["ProvBC"],
                     coefCIup["(Intercept)"]+coefCIup["ProvMB"],
                     coefCIup["(Intercept)"]+coefCIup["ProvNFImm"],
                     coefCIup["(Intercept)"]+coefCIup["ProvNFMat"],
                     coefCIup["(Intercept)"]+coefCIup["ProvNS"],
                     coefCIup["(Intercept)"]+coefCIup["ProvON"],
                     coefCIup["(Intercept)"]+coefCIup["ProvQC"],
                     coefCIup["(Intercept)"]+coefCIup["ProvSK"]))

#### CMIave ####
coef_CMIave<-function(x){
  CMIave=x
  data.table(mean=coefmean_Int+(coefmean["Y"]*(seq(min(can$Y),max(can$Y),length=600)))+(coefmean["CMIave"]*CMIave)+
               (coefmean["Y:CMIave"]*CMIave*(seq(min(can$Y),max(can$Y),length=600))),
             up=sapply(seq(min(can$Y),max(can$Y),length=600),function(x,r=CMIave){
               coefCIup_Int+(coefCIup["Y"]*x)+(coefCIup["CMIave"]*r)+(coefCIup["Y:CMIave"]*x*r)}),
             low=sapply(seq(min(can$Y),max(can$Y),length=600),function(x,r=CMIave){
               coefCIlow_Int+(coefCIlow["Y"]*x)+(coefCIlow["CMIave"]*r)+(coefCIlow["Y:CMIave"]*x*r)}),
             Y=seq(min(can$Y),max(can$Y),length=600),
             FinY=(seq(min(can$Y),max(can$Y),length=600))*sd(can$FinY)+mean(can$FinY),
             CMIaverage=CMIave)
}

to_graph<-adply(round(c(seq(quantile(can$CMIave,0.05),quantile(can$CMIave,0.95),length=4),0),2),
                .margins=1,.fun=function(x)coef_CMIave(x))
to_graph$CMIaverage<-as.factor(to_graph$CMIaverage)

round(c(seq(quantile(can$CMIave1,0.05),quantile(can$CMIave1,0.95),length=4),mean(can$CMIave1)),1)

PC2_CMIave<-ggplot(to_graph,aes(x=FinY,y=mean,col=CMIaverage,linetype=CMIaverage))+
  theme_classic()+
  geom_ribbon(aes(x=FinY,ymin=low,ymax=up,group=CMIaverage),fill="royalblue",col=NA,alpha=0.05)+
  geom_line(size=1.1)+
  scale_linetype_manual(values = c("solid","solid","solid","solid","solid"),guide=F)+
  scale_colour_manual(values=c("lightskyblue1","skyblue2","black","royalblue1","royalblue4"),
                      name="",
                      labels=c("-1.39"="1.0", "-0.53"="35.6","0.33"="70.2","1.2"="104.8","0"="Mean (56.8)"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab("Year")+
  ylab(expression(paste("Lower DT    ","(CW",M[PC2],")    Higher DT")))+
  #ylab(expression(paste("Drought tolerance"," (",-1%*%CWM[PC2],")")))+
  theme(legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))#+
#ylim(c(-1.2,1.1))
PC2_CMIave

j2 <- ggplotGrob(PC2_CMIave)

#### MATave ####
coef_MATave<-function(x){
  MATave=x
  data.table(mean=coefmean_Int+(coefmean["Y"]*(seq(min(can$Y),max(can$Y),length=600)))+(coefmean["MATave"]*MATave)+
               (coefmean["Y:MATave"]*MATave*(seq(min(can$Y),max(can$Y),length=600))),
             up=sapply(seq(min(can$Y),max(can$Y),length=600),function(x,r=MATave){
               coefCIup_Int+(coefCIup["Y"]*x)+(coefCIup["MATave"]*r)+(coefCIup["Y:MATave"]*x*r)}),
             low=sapply(seq(min(can$Y),max(can$Y),length=600),function(x,r=MATave){
               coefCIlow_Int+(coefCIlow["Y"]*x)+(coefCIlow["MATave"]*r)+(coefCIlow["Y:MATave"]*x*r)}),
             Y=seq(min(can$Y),max(can$Y),length=600),
             FinY=(seq(min(can$Y),max(can$Y),length=600))*sd(can$FinY)+mean(can$FinY),
             MATaverage=MATave)
}

to_graph<-adply(round(c(seq(quantile(can$MATave,0.05),quantile(can$MATave,0.95),length=4),0),2),
                .margins=1,.fun=function(x)coef_MATave(x))
to_graph$MATaverage<-as.factor(to_graph$MATaverage)

round(c(seq(quantile(can$MATave1,0.05),quantile(can$MATave1,0.95),length=4),mean(can$MATave1)),1)

PC2_MATave<-ggplot(to_graph,aes(x=FinY,y=mean,col=MATaverage,linetype=MATaverage))+
  theme_classic()+
  geom_ribbon(aes(x=FinY,ymin=low,ymax=up,group=MATaverage),fill="royalblue",col=NA,alpha=0.05)+
  geom_line(size=1.1)+
  scale_linetype_manual(values = c("solid","solid","solid","solid","solid"),guide=F)+
  scale_colour_manual(values=c("steelblue","olivedrab","black","goldenrod3","hotpink3"),
                      name="",
                      labels=c("-1.63"="-1.6", "-0.55"="1.3","0.53"="4.2","1.61"="7.1","0"="Mean (2.8)"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab("Year")+
  ylab(expression(paste("Lower DT    ","(CW",M[PC2],")    Higher DT")))+
  theme(legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))+
  ylim(c(-0.8,0.8))
PC2_MATave

k2 <- ggplotGrob(PC2_MATave)

#### Bind figures ####
rbind_gtable_max <- function(...){
  gtl <- list(...)
  stopifnot(all(sapply(gtl, is.gtable)))
  bind2 <- function (x, y) 
  {
    stopifnot(ncol(x) == ncol(y))
    if (nrow(x) == 0) 
      return(y)
    if (nrow(y) == 0) 
      return(x)
    y$layout$t <- y$layout$t + nrow(x)
    y$layout$b <- y$layout$b + nrow(x)
    x$layout <- rbind(x$layout, y$layout)
    x$heights <- gtable:::insert.unit(x$heights, y$heights)
    x$rownames <- c(x$rownames, y$rownames)
    x$widths <- grid::unit.pmax(x$widths, y$widths)
    x$grobs <- append(x$grobs, y$grobs)
    x
  }
  
  Reduce(bind2, gtl)
}

maxWidth = unit.pmax(j1$widths[2:3], j2$widths[2:3])
j1$widths[2:3] <- maxWidth
j2$widths[2:3] <- maxWidth

maxWidth = unit.pmax(k1$widths[2:3], k2$widths[2:3])
k1$widths[2:3] <- maxWidth
k2$widths[2:3] <- maxWidth

tiff("Fig5_MCMCglmm_FinY_effects_by_CMIave_MATave.tiff",width=3200,height=2400,res=300,compression="lzw")
grid.draw(cbind(rbind(j1,j2,size="last"),rbind(k1,k2,size="last"),size="first"))
grid.text("a",x=unit(0.013,"npc"),y=unit(0.98,"npc"),gp=gpar(fontsize=14,font=2))
grid.text("b",x=unit(0.515,"npc"),y=unit(0.98,"npc"),gp=gpar(fontsize=14,font=2))
grid.text("c",x=unit(0.013,"npc"),y=unit(0.48,"npc"),gp=gpar(fontsize=14,font=2))
grid.text("d",x=unit(0.515,"npc"),y=unit(0.48,"npc"),gp=gpar(fontsize=14,font=2))

dev.off()

#### Fig. 6 ####
#PC1 Model
m1_CAC_mcmc<-MCMCglmm(PC1~PS+Prov+
                        MEM3+MEM5+MEM6+MEM7+MEM8+MEM9+MEM12+MEM13+MEM15+MEM16+MEM20+
                        sqrtSA+CO2+ATA+ACMIA+CMIave+MATave+
                        sqrtSA:CO2+sqrtSA:ATA+sqrtSA:ACMIA+
                        sqrtSA:CMIave+sqrtSA:MATave+
                        CO2:CMIave+ATA:CMIave+ACMIA:CMIave+
                        CO2:MATave+ATA:MATave+ACMIA:MATave+
                        CMIave:MATave,
                      random = ~PLOT_ID,
                      data = can,
                      nitt = NITT, thin = THIN, burnin = BURNIN)

#save(m1_CAC_mcmc,file="m1_CAC_mcmc_th50_it53K.R")
load("m1_CAC_mcmc_th50_it53K.R")

plot(m1_CAC_mcmc$Sol[,"(Intercept)"])
plot(m1_CAC_mcmc$Sol[,"CO2:MATave"])

summary(m1_CAC_mcmc$Sol)

summary(m1_CAC_mcmc)$solutions

#an autocorrelation less than 0.1 for the first Lag
autocorr.diag(m1_CAC_mcmc$Sol[,c(1:2,23:32)])
autocorr.diag(m1_CAC_mcmc$Sol)

effectiveSize(m1_CAC_mcmc$Sol)
effectiveSize(m1_CAC_mcmc$VCV)

#PC2 Model
m2_CAC_mcmc<-MCMCglmm(PC2~PS+Prov+
                        MEM3+MEM4+MEM5+MEM6+MEM9+MEM15+MEM20+MEM22+MEM23+
                        sqrtSA+CO2+ATA+ACMIA+CMIave+MATave+
                        sqrtSA:CO2+sqrtSA:ATA+sqrtSA:ACMIA+
                        sqrtSA:CMIave+sqrtSA:MATave+
                        CO2:CMIave+ATA:CMIave+ACMIA:CMIave+
                        CO2:MATave+ATA:MATave+ACMIA:MATave+
                        CMIave:MATave,
                      random = ~PLOT_ID,
                      data = can,
                      nitt = NITT, thin = THIN, burnin = BURNIN)

#save(m2_CAC_mcmc,file="m2_CAC_mcmc_th50_it53K.R")
load("m2_CAC_mcmc_th50_it53K.R")

plot(m2_CAC_mcmc$Sol[,"(Intercept)"])
plot(m2_CAC_mcmc$Sol[,"Y:MATave"])

summary(m2_CAC_mcmc$Sol)

summary(m2_CAC_mcmc)$solutions

#an autocorrelation less than 0.1 for the first Lag
autocorr.diag(m2_CAC_mcmc$Sol)

effectiveSize(m2_CAC_mcmc$Sol)
effectiveSize(m2_CAC_mcmc$VCV)

#### Climate Interactions ####
#### PC1 ####
coefmean<-summary(m1_CAC_mcmc)$sol[,1]
coefmean_Int<-mean(c(coefmean["(Intercept)"],
                     coefmean["(Intercept)"]+coefmean["ProvAC"],
                     coefmean["(Intercept)"]+coefmean["ProvBC"],
                     coefmean["(Intercept)"]+coefmean["ProvMB"],
                     coefmean["(Intercept)"]+coefmean["ProvNFImm"],
                     coefmean["(Intercept)"]+coefmean["ProvNFMat"],
                     coefmean["(Intercept)"]+coefmean["ProvNS"],
                     coefmean["(Intercept)"]+coefmean["ProvON"],
                     coefmean["(Intercept)"]+coefmean["ProvQC"],
                     coefmean["(Intercept)"]+coefmean["ProvSK"]))

coefCIlow<-summary(m1_CAC_mcmc)$sol[,2]
coefCIlow_Int<-mean(c(coefCIlow["(Intercept)"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvAC"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvBC"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvMB"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvNFImm"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvNFMat"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvNS"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvON"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvQC"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvSK"]))

coefCIup<-summary(m1_CAC_mcmc)$sol[,3]
coefCIup_Int<-mean(c(coefCIup["(Intercept)"],
                     coefCIup["(Intercept)"]+coefCIup["ProvAC"],
                     coefCIup["(Intercept)"]+coefCIup["ProvBC"],
                     coefCIup["(Intercept)"]+coefCIup["ProvMB"],
                     coefCIup["(Intercept)"]+coefCIup["ProvNFImm"],
                     coefCIup["(Intercept)"]+coefCIup["ProvNFMat"],
                     coefCIup["(Intercept)"]+coefCIup["ProvNS"],
                     coefCIup["(Intercept)"]+coefCIup["ProvON"],
                     coefCIup["(Intercept)"]+coefCIup["ProvQC"],
                     coefCIup["(Intercept)"]+coefCIup["ProvSK"]))
#### CO2 ####
#### CMIave ####
coef_CMIave<-function(x){
  CMIave=x
  data.table(mean=coefmean_Int+(coefmean["CO2"]*(seq(min(can$CO2),max(can$CO2),length=600)))+(coefmean["CMIave"]*CMIave)+
               (coefmean["CO2:CMIave"]*CMIave*(seq(min(can$CO2),max(can$CO2),length=600))),
             up=sapply(seq(min(can$CO2),max(can$CO2),length=600),function(x,r=CMIave){
               coefCIup_Int+(coefCIup["CO2"]*x)+(coefCIup["CMIave"]*r)+(coefCIup["CO2:CMIave"]*x*r)}),
             low=sapply(seq(min(can$CO2),max(can$CO2),length=600),function(x,r=CMIave){
               coefCIlow_Int+(coefCIlow["CO2"]*x)+(coefCIlow["CMIave"]*r)+(coefCIlow["CO2:CMIave"]*x*r)}),
             CO2=seq(min(can$CO2),max(can$CO2),length=600),
             CO21=(seq(min(can$CO2),max(can$CO2),length=600))*sd(can$CO21)+mean(can$CO21),
             CMIaverage=CMIave)
}

to_graph<-adply(round(c(seq(quantile(can$CMIave,0.05),quantile(can$CMIave,0.95),length=4),0),2),
                .margins=1,.fun=function(x)coef_CMIave(x))
to_graph$CMIaverage<-as.factor(to_graph$CMIaverage)

round(c(seq(quantile(can$CMIave1,0.05),quantile(can$CMIave1,0.95),length=4),mean(can$CMIave1)),1)

PC1_CMIave_CO2<-ggplot(to_graph,aes(x=CO21,y=mean,col=CMIaverage,linetype=CMIaverage))+
  theme_classic()+
  geom_ribbon(aes(x=CO21,ymin=low,ymax=up,group=CMIaverage),fill="royalblue",col=NA,alpha=0.05)+
  geom_line(size=1.1)+
  scale_linetype_manual(values = c("solid","solid","solid","solid","solid"),guide=F)+
  scale_colour_manual(values=c("lightskyblue1","skyblue2","black","royalblue1","royalblue4"),
                      name="",
                      labels=c("-1.39"="1.0", "-0.53"="35.6","0.33"="70.2","1.2"="104.8","0"="Mean (56.8)"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab("")+
  ylab(expression(paste("Conifers    (",CWM[PC1],")    DB")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x=element_blank(), axis.line.y = element_line())+
  guides(col=FALSE)+
  ylim(c(-3.2,2))
PC1_CMIave_CO2

c1 <- ggplotGrob(PC1_CMIave_CO2)

#### MATave ####
coef_MATave<-function(x){
  MATave=x
  data.table(mean=coefmean_Int+(coefmean["CO2"]*(seq(min(can$CO2),max(can$CO2),length=600)))+(coefmean["MATave"]*MATave)+
               (coefmean["CO2:MATave"]*MATave*(seq(min(can$CO2),max(can$CO2),length=600))),
             up=sapply(seq(min(can$CO2),max(can$CO2),length=600),function(x,r=MATave){
               coefCIup_Int+(coefCIup["CO2"]*x)+(coefCIup["MATave"]*r)+(coefCIup["CO2:MATave"]*x*r)}),
             low=sapply(seq(min(can$CO2),max(can$CO2),length=600),function(x,r=MATave){
               coefCIlow_Int+(coefCIlow["CO2"]*x)+(coefCIlow["MATave"]*r)+(coefCIlow["CO2:MATave"]*x*r)}),
             CO2=seq(min(can$CO2),max(can$CO2),length=600),
             CO21=(seq(min(can$CO2),max(can$CO2),length=600))*sd(can$CO21)+mean(can$CO21),
             MATaverage=MATave)
}

to_graph<-adply(round(c(seq(quantile(can$MATave,0.05),quantile(can$MATave,0.95),length=4),0),2),
                .margins=1,.fun=function(x)coef_MATave(x))
to_graph$MATaverage<-as.factor(to_graph$MATaverage)

round(c(seq(quantile(can$MATave1,0.05),quantile(can$MATave1,0.95),length=4),mean(can$MATave1)),1)

PC1_MATave_CO2<-ggplot(to_graph,aes(x=CO21,y=mean,col=MATaverage,linetype=MATaverage))+
  theme_classic()+
  geom_ribbon(aes(x=CO21,ymin=low,ymax=up,group=MATaverage),fill="royalblue",col=NA,alpha=0.05)+
  geom_line(size=1.1)+
  scale_linetype_manual(values = c("solid","solid","solid","solid","solid"),guide=F)+
  scale_colour_manual(values=c("steelblue","olivedrab","black","goldenrod3","hotpink3"),
                      name="",
                      labels=c("-1.63"="-1.6", "-0.55"="1.3","0.53"="4.2","1.61"="7.1","0"="Mean (2.8)"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab("")+
  ylab(expression(paste("Conifers    (",CWM[PC1],")    DB")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line())+
  guides(col=FALSE)+
  ylim(c(-3.2,2))
PC1_MATave_CO2

C1 <- ggplotGrob(PC1_MATave_CO2)

#### ATA ####
#### CMIave ####
coef_CMIave<-function(x){
  CMIave=x
  data.table(mean=coefmean_Int+(coefmean["ATA"]*(seq(min(can$ATA),max(can$ATA),length=600)))+(coefmean["CMIave"]*CMIave)+
               (coefmean["ATA:CMIave"]*CMIave*(seq(min(can$ATA),max(can$ATA),length=600))),
             up=sapply(seq(min(can$ATA),max(can$ATA),length=600),function(x,r=CMIave){
               coefCIup_Int+(coefCIup["ATA"]*x)+(coefCIup["CMIave"]*r)+(coefCIup["ATA:CMIave"]*x*r)}),
             low=sapply(seq(min(can$ATA),max(can$ATA),length=600),function(x,r=CMIave){
               coefCIlow_Int+(coefCIlow["ATA"]*x)+(coefCIlow["CMIave"]*r)+(coefCIlow["ATA:CMIave"]*x*r)}),
             ATA=seq(min(can$ATA),max(can$ATA),length=600),
             ATA1=(seq(min(can$ATA),max(can$ATA),length=600))*sd(can$ATA1)+mean(can$ATA1),
             CMIaverage=CMIave)
}

to_graph<-adply(round(c(seq(quantile(can$CMIave,0.05),quantile(can$CMIave,0.95),length=4),0),2),
                .margins=1,.fun=function(x)coef_CMIave(x))
to_graph$CMIaverage<-as.factor(to_graph$CMIaverage)

round(c(seq(quantile(can$CMIave1,0.05),quantile(can$CMIave1,0.95),length=4),mean(can$CMIave1)),1)

PC1_CMIave_ATA<-ggplot(to_graph,aes(x=ATA1,y=mean,col=CMIaverage,linetype=CMIaverage))+
  theme_classic()+
  geom_ribbon(aes(x=ATA1,ymin=low,ymax=up,group=CMIaverage),fill="royalblue",col=NA,alpha=0.05)+
  geom_line(size=1.1)+
  scale_linetype_manual(values = c("solid","solid","solid","solid","solid"),guide=F)+
  scale_colour_manual(values=c("lightskyblue1","skyblue2","black","royalblue1","royalblue4"),
                      name="",
                      labels=c("-1.39"="1.0", "-0.53"="35.6","0.33"="70.2","1.2"="104.8","0"="Mean (56.8)"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab("")+
  ylab(expression(paste("Conifers    (",CWM[PC1],")    DB")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x=element_blank(), axis.line.y = element_line())+
  guides(col=FALSE)+
  ylim(c(-3.2,2))+
  xlim(c(quantile(can$ATA1,0.05),quantile(can$ATA1,0.95)))
PC1_CMIave_ATA

t1 <- ggplotGrob(PC1_CMIave_ATA)

#### MATave ####
coef_MATave<-function(x){
  MATave=x
  data.table(mean=coefmean_Int+(coefmean["ATA"]*(seq(min(can$ATA),max(can$ATA),length=600)))+(coefmean["MATave"]*MATave)+
               (coefmean["ATA:MATave"]*MATave*(seq(min(can$ATA),max(can$ATA),length=600))),
             up=sapply(seq(min(can$ATA),max(can$ATA),length=600),function(x,r=MATave){
               coefCIup_Int+(coefCIup["ATA"]*x)+(coefCIup["MATave"]*r)+(coefCIup["ATA:MATave"]*x*r)}),
             low=sapply(seq(min(can$ATA),max(can$ATA),length=600),function(x,r=MATave){
               coefCIlow_Int+(coefCIlow["ATA"]*x)+(coefCIlow["MATave"]*r)+(coefCIlow["ATA:MATave"]*x*r)}),
             ATA=seq(min(can$ATA),max(can$ATA),length=600),
             ATA1=(seq(min(can$ATA),max(can$ATA),length=600))*sd(can$ATA1)+mean(can$ATA1),
             MATaverage=MATave)
}

to_graph<-adply(round(c(seq(quantile(can$MATave,0.05),quantile(can$MATave,0.95),length=4),0),2),
                .margins=1,.fun=function(x)coef_MATave(x))
to_graph$MATaverage<-as.factor(to_graph$MATaverage)

round(c(seq(quantile(can$MATave1,0.05),quantile(can$MATave1,0.95),length=4),mean(can$MATave1)),1)

PC1_MATave_ATA<-ggplot(to_graph,aes(x=ATA1,y=mean,col=MATaverage,linetype=MATaverage))+
  theme_classic()+
  geom_ribbon(aes(x=ATA1,ymin=low,ymax=up,group=MATaverage),fill="royalblue",col=NA,alpha=0.05)+
  geom_line(size=1.1)+
  scale_linetype_manual(values = c("solid","solid","solid","solid","solid"),guide=F)+
  scale_colour_manual(values=c("steelblue","olivedrab","black","goldenrod3","hotpink3"),
                      name="",
                      labels=c("-1.63"="-1.6", "-0.55"="1.3","0.53"="4.2","1.61"="7.1","0"="Mean (2.8)"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab("")+
  ylab(expression(paste("Conifers    (",CWM[PC1],")    DB")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line())+
  guides(col=FALSE)+
  ylim(c(-3.2,2))+
  xlim(c(quantile(can$ATA1,0.05),quantile(can$ATA1,0.95)))
PC1_MATave_ATA

T1 <- ggplotGrob(PC1_MATave_ATA)

#### ACMIA ####
#### CMIave ####
coef_CMIave<-function(x){
  CMIave=x
  data.table(mean=coefmean_Int+(coefmean["ACMIA"]*(seq(min(can$ACMIA),max(can$ACMIA),length=600)))+(coefmean["CMIave"]*CMIave)+
               (coefmean["ACMIA:CMIave"]*CMIave*(seq(min(can$ACMIA),max(can$ACMIA),length=600))),
             up=sapply(seq(min(can$ACMIA),max(can$ACMIA),length=600),function(x,r=CMIave){
               coefCIup_Int+(coefCIup["ACMIA"]*x)+(coefCIup["CMIave"]*r)+(coefCIup["ACMIA:CMIave"]*x*r)}),
             low=sapply(seq(min(can$ACMIA),max(can$ACMIA),length=600),function(x,r=CMIave){
               coefCIlow_Int+(coefCIlow["ACMIA"]*x)+(coefCIlow["CMIave"]*r)+(coefCIlow["ACMIA:CMIave"]*x*r)}),
             ACMIA=seq(min(can$ACMIA),max(can$ACMIA),length=600),
             ACMIA1=(seq(min(can$ACMIA),max(can$ACMIA),length=600))*sd(can$ACMIA1)+mean(can$ACMIA1),
             CMIaverage=CMIave)
}

to_graph<-adply(round(c(seq(quantile(can$CMIave,0.05),quantile(can$CMIave,0.95),length=4),0),2),
                .margins=1,.fun=function(x)coef_CMIave(x))
to_graph$CMIaverage<-as.factor(to_graph$CMIaverage)

round(c(seq(quantile(can$CMIave1,0.05),quantile(can$CMIave1,0.95),length=4),mean(can$CMIave1)),1)

PC1_CMIave_ACMIA<-ggplot(to_graph,aes(x=ACMIA1,y=mean,col=CMIaverage,linetype=CMIaverage))+
  theme_classic()+
  geom_ribbon(aes(x=ACMIA1,ymin=low,ymax=up,group=CMIaverage),fill="royalblue",col=NA,alpha=0.05)+
  geom_line(size=1.1)+
  scale_linetype_manual(values = c("solid","solid","solid","solid","solid"),guide=F)+
  scale_colour_manual(values=c("lightskyblue1","skyblue2","black","royalblue1","royalblue4"),
                      name=expression(paste(CMI[ave]," (cm)")),
                      labels=c("-1.39"="1.0", "-0.53"="35.6","0.33"="70.2","1.2"="104.8","0"="Mean (56.8)"))+
  xlab("")+
  ylab(expression(paste("Conifers    (",CWM[PC1],")    DB")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x=element_blank(), axis.line.y = element_line())+
  ylim(c(-3.2,2))+
  xlim(c(quantile(can$ACMIA1,0.05),quantile(can$ACMIA1,0.95)))
PC1_CMIave_ACMIA

a1 <- ggplotGrob(PC1_CMIave_ACMIA)

#### MATave ####
coef_MATave<-function(x){
  MATave=x
  data.table(mean=coefmean_Int+(coefmean["ACMIA"]*(seq(min(can$ACMIA),max(can$ACMIA),length=600)))+(coefmean["MATave"]*MATave)+
               (coefmean["ACMIA:MATave"]*MATave*(seq(min(can$ACMIA),max(can$ACMIA),length=600))),
             up=sapply(seq(min(can$ACMIA),max(can$ACMIA),length=600),function(x,r=MATave){
               coefCIup_Int+(coefCIup["ACMIA"]*x)+(coefCIup["MATave"]*r)+(coefCIup["ACMIA:MATave"]*x*r)}),
             low=sapply(seq(min(can$ACMIA),max(can$ACMIA),length=600),function(x,r=MATave){
               coefCIlow_Int+(coefCIlow["ACMIA"]*x)+(coefCIlow["MATave"]*r)+(coefCIlow["ACMIA:MATave"]*x*r)}),
             ACMIA=seq(min(can$ACMIA),max(can$ACMIA),length=600),
             ACMIA1=(seq(min(can$ACMIA),max(can$ACMIA),length=600))*sd(can$ACMIA1)+mean(can$ACMIA1),
             MATaverage=MATave)
}

to_graph<-adply(round(c(seq(quantile(can$MATave,0.05),quantile(can$MATave,0.95),length=4),0),2),
                .margins=1,.fun=function(x)coef_MATave(x))
to_graph$MATaverage<-as.factor(to_graph$MATaverage)

round(c(seq(quantile(can$MATave1,0.05),quantile(can$MATave1,0.95),length=4),mean(can$MATave1)),1)

PC1_MATave_ACMIA<-ggplot(to_graph,aes(x=ACMIA1,y=mean,col=MATaverage,linetype=MATaverage))+
  theme_classic()+
  geom_ribbon(aes(x=ACMIA1,ymin=low,ymax=up,group=MATaverage),fill="royalblue",col=NA,alpha=0.05)+
  geom_line(size=1.1)+
  scale_linetype_manual(values = c("solid","solid","solid","solid","solid"),guide=F)+
  scale_colour_manual(values=c("steelblue","olivedrab","black","goldenrod3","hotpink3"),
                      name=expression(paste(MAT[ave]," (",~degree*C,")")),
                      labels=c("-1.63"="-1.6", "-0.55"="1.3","0.53"="4.2","1.61"="7.1","0"="Mean (2.8)"))+
  xlab("")+
  ylab(expression(paste("Conifers    (",CWM[PC1],")    DB")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line())+
  ylim(c(-3.2,2))+
  xlim(c(quantile(can$ACMIA1,0.05),quantile(can$ACMIA1,0.95)))
PC1_MATave_ACMIA

A1 <- ggplotGrob(PC1_MATave_ACMIA)

#### PC2 ####
coefmean<-summary(m2_CAC_mcmc)$sol[,1]
coefmean_Int<-mean(c(coefmean["(Intercept)"],
                     coefmean["(Intercept)"]+coefmean["ProvAC"],
                     coefmean["(Intercept)"]+coefmean["ProvBC"],
                     coefmean["(Intercept)"]+coefmean["ProvMB"],
                     coefmean["(Intercept)"]+coefmean["ProvNFImm"],
                     coefmean["(Intercept)"]+coefmean["ProvNFMat"],
                     coefmean["(Intercept)"]+coefmean["ProvNS"],
                     coefmean["(Intercept)"]+coefmean["ProvON"],
                     coefmean["(Intercept)"]+coefmean["ProvQC"],
                     coefmean["(Intercept)"]+coefmean["ProvSK"]))

coefCIlow<-summary(m2_CAC_mcmc)$sol[,2]
coefCIlow_Int<-mean(c(coefCIlow["(Intercept)"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvAC"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvBC"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvMB"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvNFImm"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvNFMat"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvNS"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvON"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvQC"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvSK"]))

coefCIup<-summary(m2_CAC_mcmc)$sol[,3]
coefCIup_Int<-mean(c(coefCIup["(Intercept)"],
                     coefCIup["(Intercept)"]+coefCIup["ProvAC"],
                     coefCIup["(Intercept)"]+coefCIup["ProvBC"],
                     coefCIup["(Intercept)"]+coefCIup["ProvMB"],
                     coefCIup["(Intercept)"]+coefCIup["ProvNFImm"],
                     coefCIup["(Intercept)"]+coefCIup["ProvNFMat"],
                     coefCIup["(Intercept)"]+coefCIup["ProvNS"],
                     coefCIup["(Intercept)"]+coefCIup["ProvON"],
                     coefCIup["(Intercept)"]+coefCIup["ProvQC"],
                     coefCIup["(Intercept)"]+coefCIup["ProvSK"]))
#### CO2 ####
#### CMIave ####
coef_CMIave<-function(x){
  CMIave=x
  data.table(mean=coefmean_Int+(coefmean["CO2"]*(seq(min(can$CO2),max(can$CO2),length=600)))+(coefmean["CMIave"]*CMIave)+
               (coefmean["CO2:CMIave"]*CMIave*(seq(min(can$CO2),max(can$CO2),length=600))),
             up=sapply(seq(min(can$CO2),max(can$CO2),length=600),function(x,r=CMIave){
               coefCIup_Int+(coefCIup["CO2"]*x)+(coefCIup["CMIave"]*r)+(coefCIup["CO2:CMIave"]*x*r)}),
             low=sapply(seq(min(can$CO2),max(can$CO2),length=600),function(x,r=CMIave){
               coefCIlow_Int+(coefCIlow["CO2"]*x)+(coefCIlow["CMIave"]*r)+(coefCIlow["CO2:CMIave"]*x*r)}),
             CO2=seq(min(can$CO2),max(can$CO2),length=600),
             CO21=(seq(min(can$CO2),max(can$CO2),length=600))*sd(can$CO21)+mean(can$CO21),
             CMIaverage=CMIave)
}

to_graph<-adply(round(c(seq(quantile(can$CMIave,0.05),quantile(can$CMIave,0.95),length=4),0),2),
                .margins=1,.fun=function(x)coef_CMIave(x))
to_graph$CMIaverage<-as.factor(to_graph$CMIaverage)

round(c(seq(quantile(can$CMIave1,0.05),quantile(can$CMIave1,0.95),length=4),mean(can$CMIave1)),1)

PC2_CMIave_CO2<-ggplot(to_graph,aes(x=CO21,y=mean,col=CMIaverage,linetype=CMIaverage))+
  theme_classic()+
  geom_ribbon(aes(x=CO21,ymin=low,ymax=up,group=CMIaverage),fill="royalblue",col=NA,alpha=0.05)+
  geom_line(size=1.1)+
  scale_linetype_manual(values = c("solid","solid","solid","solid","solid"),guide=F)+
  scale_colour_manual(values=c("lightskyblue1","skyblue2","black","royalblue1","royalblue4"),
                      name=expression(paste(CMI[ave]," (cm)")),
                      labels=c("-1.39"="1.0", "-0.53"="35.6","0.33"="70.2","1.2"="104.8","0"="Mean (56.8)"))+
  xlab(expression(paste(CO[2]," (ppm)")))+
  ylab(expression(paste("Low DT  ","CW",M[PC2],"  High DT")))+
  theme(legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))+
  guides(col=FALSE)+
  ylim(c(-1.2,1.1))
PC2_CMIave_CO2

c2 <- ggplotGrob(PC2_CMIave_CO2)

#### MATave ####
coef_MATave<-function(x){
  MATave=x
  data.table(mean=coefmean_Int+(coefmean["CO2"]*(seq(min(can$CO2),max(can$CO2),length=600)))+(coefmean["MATave"]*MATave)+
               (coefmean["CO2:MATave"]*MATave*(seq(min(can$CO2),max(can$CO2),length=600))),
             up=sapply(seq(min(can$CO2),max(can$CO2),length=600),function(x,r=MATave){
               coefCIup_Int+(coefCIup["CO2"]*x)+(coefCIup["MATave"]*r)+(coefCIup["CO2:MATave"]*x*r)}),
             low=sapply(seq(min(can$CO2),max(can$CO2),length=600),function(x,r=MATave){
               coefCIlow_Int+(coefCIlow["CO2"]*x)+(coefCIlow["MATave"]*r)+(coefCIlow["CO2:MATave"]*x*r)}),
             CO2=seq(min(can$CO2),max(can$CO2),length=600),
             CO21=(seq(min(can$CO2),max(can$CO2),length=600))*sd(can$CO21)+mean(can$CO21),
             MATaverage=MATave)
}

to_graph<-adply(round(c(seq(quantile(can$MATave,0.05),quantile(can$MATave,0.95),length=4),0),2),
                .margins=1,.fun=function(x)coef_MATave(x))
to_graph$MATaverage<-as.factor(to_graph$MATaverage)

round(c(seq(quantile(can$MATave1,0.05),quantile(can$MATave1,0.95),length=4),mean(can$MATave1)),1)

PC2_MATave_CO2<-ggplot(to_graph,aes(x=CO21,y=mean,col=MATaverage,linetype=MATaverage))+
  theme_classic()+
  geom_ribbon(aes(x=CO21,ymin=low,ymax=up,group=MATaverage),fill="royalblue",col=NA,alpha=0.05)+
  geom_line(size=1.1)+
  scale_linetype_manual(values = c("solid","solid","solid","solid","solid"),guide=F)+
  scale_colour_manual(values=c("steelblue","olivedrab","black","goldenrod3","hotpink3"),
                      name=expression(paste(MAT[ave]," (",~degree*C,")")),
                      labels=c("-1.63"="-1.6", "-0.55"="1.3","0.53"="4.2","1.61"="7.1","0"="Mean (2.8)"))+
  xlab(expression(paste(CO[2]," (ppm)")))+
  ylab(expression(paste("Low DT  ","CW",M[PC2],"  High DT")))+
  theme(legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))+
  guides(col=FALSE)+
  ylim(c(-0.8,0.8))
PC2_MATave_CO2

C2 <- ggplotGrob(PC2_MATave_CO2)

#### ATA ####
#### CMIave ####
coef_CMIave<-function(x){
  CMIave=x
  data.table(mean=coefmean_Int+(coefmean["ATA"]*(seq(min(can$ATA),max(can$ATA),length=600)))+(coefmean["CMIave"]*CMIave)+
               (coefmean["ATA:CMIave"]*CMIave*(seq(min(can$ATA),max(can$ATA),length=600))),
             up=sapply(seq(min(can$ATA),max(can$ATA),length=600),function(x,r=CMIave){
               coefCIup_Int+(coefCIup["ATA"]*x)+(coefCIup["CMIave"]*r)+(coefCIup["ATA:CMIave"]*x*r)}),
             low=sapply(seq(min(can$ATA),max(can$ATA),length=600),function(x,r=CMIave){
               coefCIlow_Int+(coefCIlow["ATA"]*x)+(coefCIlow["CMIave"]*r)+(coefCIlow["ATA:CMIave"]*x*r)}),
             ATA=seq(min(can$ATA),max(can$ATA),length=600),
             ATA1=(seq(min(can$ATA),max(can$ATA),length=600))*sd(can$ATA1)+mean(can$ATA1),
             CMIaverage=CMIave)
}

to_graph<-adply(round(c(seq(quantile(can$CMIave,0.05),quantile(can$CMIave,0.95),length=4),0),2),
                .margins=1,.fun=function(x)coef_CMIave(x))
to_graph$CMIaverage<-as.factor(to_graph$CMIaverage)

round(c(seq(quantile(can$CMIave1,0.05),quantile(can$CMIave1,0.95),length=4),mean(can$CMIave1)),1)

PC2_CMIave_ATA<-ggplot(to_graph,aes(x=ATA1,y=mean,col=CMIaverage,linetype=CMIaverage))+
  theme_classic()+
  geom_ribbon(aes(x=ATA1,ymin=low,ymax=up,group=CMIaverage),fill="royalblue",col=NA,alpha=0.05)+
  geom_line(size=1.1)+
  scale_linetype_manual(values = c("solid","solid","solid","solid","solid"),guide=F)+
  scale_colour_manual(values=c("lightskyblue1","skyblue2","black","royalblue1","royalblue4"),
                      name=expression(paste(CMI[ave]," (cm)")),
                      labels=c("-1.39"="1.0", "-0.53"="35.6","0.33"="70.2","1.2"="104.8","0"="Mean (56.8)"))+
  xlab(expression(paste("ATA (",~degree*C,")")))+
  ylab(expression(paste("Low DT  ","CW",M[PC2],"  High DT")))+
  theme(legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))+
  guides(col=FALSE)+
  ylim(c(-1.2,1.1))+
  xlim(c(quantile(can$ATA1,0.05),quantile(can$ATA1,0.95)))
PC2_CMIave_ATA

t2 <- ggplotGrob(PC2_CMIave_ATA)

#### MATave ####
coef_MATave<-function(x){
  MATave=x
  data.table(mean=coefmean_Int+(coefmean["ATA"]*(seq(min(can$ATA),max(can$ATA),length=600)))+(coefmean["MATave"]*MATave)+
               (coefmean["ATA:MATave"]*MATave*(seq(min(can$ATA),max(can$ATA),length=600))),
             up=sapply(seq(min(can$ATA),max(can$ATA),length=600),function(x,r=MATave){
               coefCIup_Int+(coefCIup["ATA"]*x)+(coefCIup["MATave"]*r)+(coefCIup["ATA:MATave"]*x*r)}),
             low=sapply(seq(min(can$ATA),max(can$ATA),length=600),function(x,r=MATave){
               coefCIlow_Int+(coefCIlow["ATA"]*x)+(coefCIlow["MATave"]*r)+(coefCIlow["ATA:MATave"]*x*r)}),
             ATA=seq(min(can$ATA),max(can$ATA),length=600),
             ATA1=(seq(min(can$ATA),max(can$ATA),length=600))*sd(can$ATA1)+mean(can$ATA1),
             MATaverage=MATave)
}

to_graph<-adply(round(c(seq(quantile(can$MATave,0.05),quantile(can$MATave,0.95),length=4),0),2),
                .margins=1,.fun=function(x)coef_MATave(x))
to_graph$MATaverage<-as.factor(to_graph$MATaverage)

round(c(seq(quantile(can$MATave1,0.05),quantile(can$MATave1,0.95),length=4),mean(can$MATave1)),1)

PC2_MATave_ATA<-ggplot(to_graph,aes(x=ATA1,y=mean,col=MATaverage,linetype=MATaverage))+
  theme_classic()+
  geom_ribbon(aes(x=ATA1,ymin=low,ymax=up,group=MATaverage),fill="royalblue",col=NA,alpha=0.05)+
  geom_line(size=1.1)+
  scale_linetype_manual(values = c("solid","solid","solid","solid","solid"),guide=F)+
  scale_colour_manual(values=c("steelblue","olivedrab","black","goldenrod3","hotpink3"),
                      name=expression(paste(MAT[ave]," (",~degree*C,")")),
                      labels=c("-1.63"="-1.6", "-0.55"="1.3","0.53"="4.2","1.61"="7.1","0"="Mean (2.8)"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab(expression(paste("ATA (",~degree*C,")")))+
  ylab(expression(paste("Low DT  ","CW",M[PC2],"  High DT")))+
  theme_classic()+
  theme(legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))+
  guides(col=FALSE)+
  ylim(c(-0.8,0.8))+
  xlim(c(quantile(can$ATA1,0.05),quantile(can$ATA1,0.95)))
PC2_MATave_ATA

T2 <- ggplotGrob(PC2_MATave_ATA)

#### ACMIA ####
#### CMIave ####
coef_CMIave<-function(x){
  CMIave=x
  data.table(mean=coefmean_Int+(coefmean["ACMIA"]*(seq(min(can$ACMIA),max(can$ACMIA),length=600)))+(coefmean["CMIave"]*CMIave)+
               (coefmean["ACMIA:CMIave"]*CMIave*(seq(min(can$ACMIA),max(can$ACMIA),length=600))),
             up=sapply(seq(min(can$ACMIA),max(can$ACMIA),length=600),function(x,r=CMIave){
               coefCIup_Int+(coefCIup["ACMIA"]*x)+(coefCIup["CMIave"]*r)+(coefCIup["ACMIA:CMIave"]*x*r)}),
             low=sapply(seq(min(can$ACMIA),max(can$ACMIA),length=600),function(x,r=CMIave){
               coefCIlow_Int+(coefCIlow["ACMIA"]*x)+(coefCIlow["CMIave"]*r)+(coefCIlow["ACMIA:CMIave"]*x*r)}),
             ACMIA=seq(min(can$ACMIA),max(can$ACMIA),length=600),
             ACMIA1=(seq(min(can$ACMIA),max(can$ACMIA),length=600))*sd(can$ACMIA1)+mean(can$ACMIA1),
             CMIaverage=CMIave)
}

to_graph<-adply(round(c(seq(quantile(can$CMIave,0.05),quantile(can$CMIave,0.95),length=4),0),2),
                .margins=1,.fun=function(x)coef_CMIave(x))
to_graph$CMIaverage<-as.factor(to_graph$CMIaverage)

round(c(seq(quantile(can$CMIave1,0.05),quantile(can$CMIave1,0.95),length=4),mean(can$CMIave1)),1)

PC2_CMIave_ACMIA<-ggplot(to_graph,aes(x=ACMIA1,y=mean,col=CMIaverage,linetype=CMIaverage))+
  theme_classic()+
  geom_ribbon(aes(x=ACMIA1,ymin=low,ymax=up,group=CMIaverage),fill="royalblue",col=NA,alpha=0.05)+
  geom_line(size=1.1)+
  scale_linetype_manual(values = c("solid","solid","solid","solid","solid"),guide=F)+
  scale_colour_manual(values=c("lightskyblue1","skyblue2","black","royalblue1","royalblue4"),
                      name="",
                      labels=c("-1.39"="1.0", "-0.53"="35.6","0.33"="70.2","1.2"="104.8","0"="Mean (56.8)"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab(expression(paste("ACMIA (cm)")))+
  ylab(expression(paste("Low DT  ","CW",M[PC2],"  High DT")))+
  theme_classic()+
  theme(legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))+
  ylim(c(-1.2,1.1))+
  xlim(c(quantile(can$ACMIA1,0.05),quantile(can$ACMIA1,0.95)))
PC2_CMIave_ACMIA

a2 <- ggplotGrob(PC2_CMIave_ACMIA)

#### MATave ####
coef_MATave<-function(x){
  MATave=x
  data.table(mean=coefmean_Int+(coefmean["ACMIA"]*(seq(min(can$ACMIA),max(can$ACMIA),length=600)))+(coefmean["MATave"]*MATave)+
               (coefmean["ACMIA:MATave"]*MATave*(seq(min(can$ACMIA),max(can$ACMIA),length=600))),
             up=sapply(seq(min(can$ACMIA),max(can$ACMIA),length=600),function(x,r=MATave){
               coefCIup_Int+(coefCIup["ACMIA"]*x)+(coefCIup["MATave"]*r)+(coefCIup["ACMIA:MATave"]*x*r)}),
             low=sapply(seq(min(can$ACMIA),max(can$ACMIA),length=600),function(x,r=MATave){
               coefCIlow_Int+(coefCIlow["ACMIA"]*x)+(coefCIlow["MATave"]*r)+(coefCIlow["ACMIA:MATave"]*x*r)}),
             ACMIA=seq(min(can$ACMIA),max(can$ACMIA),length=600),
             ACMIA1=(seq(min(can$ACMIA),max(can$ACMIA),length=600))*sd(can$ACMIA1)+mean(can$ACMIA1),
             MATaverage=MATave)
}

to_graph<-adply(round(c(seq(quantile(can$MATave,0.05),quantile(can$MATave,0.95),length=4),0),2),
                .margins=1,.fun=function(x)coef_MATave(x))
to_graph$MATaverage<-as.factor(to_graph$MATaverage)

round(c(seq(quantile(can$MATave1,0.05),quantile(can$MATave1,0.95),length=4),mean(can$MATave1)),1)

PC2_MATave_ACMIA<-ggplot(to_graph,aes(x=ACMIA1,y=mean,col=MATaverage,linetype=MATaverage))+
  theme_classic()+
  geom_ribbon(aes(x=ACMIA1,ymin=low,ymax=up,group=MATaverage),fill="royalblue",col=NA,alpha=0.05)+
  geom_line(size=1.1)+
  scale_linetype_manual(values = c("solid","solid","solid","solid","solid"),guide=F)+
  scale_colour_manual(values=c("steelblue","olivedrab","black","goldenrod3","hotpink3"),
                      name="",
                      labels=c("-1.63"="-1.6", "-0.55"="1.3","0.53"="4.2","1.61"="7.1","0"="Mean (2.8)"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab(expression(paste("ACMIA (cm)")))+
  ylab(expression(paste("Low DT  ","CW",M[PC2],"  High DT")))+
  theme_classic()+
  theme(legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))+
  ylim(c(-0.8,0.8))+
  xlim(c(quantile(can$ACMIA1,0.05),quantile(can$ACMIA1,0.95)))
PC2_MATave_ACMIA

A2 <- ggplotGrob(PC2_MATave_ACMIA)

############ BIND ALL (CMIave & MATave) ############
rbind_gtable_max <- function(...){
  gtl <- list(...)
  stopifnot(all(sapply(gtl, is.gtable)))
  bind2 <- function (x, y) 
  {
    stopifnot(ncol(x) == ncol(y))
    if (nrow(x) == 0) 
      return(y)
    if (nrow(y) == 0) 
      return(x)
    y$layout$t <- y$layout$t + nrow(x)
    y$layout$b <- y$layout$b + nrow(x)
    x$layout <- rbind(x$layout, y$layout)
    x$heights <- gtable:::insert.unit(x$heights, y$heights)
    x$rownames <- c(x$rownames, y$rownames)
    x$widths <- grid::unit.pmax(x$widths, y$widths)
    x$grobs <- append(x$grobs, y$grobs)
    x
  }
  
  Reduce(bind2, gtl)
}

maxWidth = unit.pmax(c1$widths[2:3], c2$widths[2:3])
c1$widths[2:3] <- maxWidth
c2$widths[2:3] <- maxWidth

maxWidth = unit.pmax(t1$widths[2:3], t2$widths[2:3])
t1$widths[2:3] <- maxWidth
t2$widths[2:3] <- maxWidth

maxWidth = unit.pmax(a1$widths[2:3], a2$widths[2:3])
a1$widths[2:3] <- maxWidth
a2$widths[2:3] <- maxWidth

maxWidth = unit.pmax(C1$widths[2:3], C2$widths[2:3])
C1$widths[2:3] <- maxWidth
C2$widths[2:3] <- maxWidth

maxWidth = unit.pmax(T1$widths[2:3], T2$widths[2:3])
T1$widths[2:3] <- maxWidth
T2$widths[2:3] <- maxWidth

maxWidth = unit.pmax(A1$widths[2:3], A2$widths[2:3])
A1$widths[2:3] <- maxWidth
A2$widths[2:3] <- maxWidth

tiff("Fig6_MCMCglmm_Climate_slopes_by_CMIave_MATave_BIND.tiff",width=3000,height=3000,res=300,compression="lzw")
grid.draw(cbind(rbind(c1,c2,C1,C2,size="last"),rbind(t1,t2,T1,T2,size="last"),
                rbind(a1,a2,A1,A2,size="last"),size="first"))
grid.text("a",x=unit(0.016+0.056,"npc"),y=unit(0.985,"npc"),gp=gpar(fontsize=14,font=2))
grid.text("b",x=unit(0.31+0.055,"npc"),y=unit(0.985,"npc"),gp=gpar(fontsize=14,font=2))
grid.text("c",x=unit(0.60+0.055,"npc"),y=unit(0.985,"npc"),gp=gpar(fontsize=14,font=2))
grid.text("d",x=unit(0.016+0.056,"npc"),y=unit(0.485,"npc"),gp=gpar(fontsize=14,font=2))
grid.text("e",x=unit(0.31+0.055,"npc"),y=unit(0.485,"npc"),gp=gpar(fontsize=14,font=2))
grid.text("f",x=unit(0.60+0.055,"npc"),y=unit(0.485,"npc"),gp=gpar(fontsize=14,font=2))
#grid.lines(x = unit(c(0,1), "npc"),y = unit(c(0.5, 0.5), "npc"),default.units = "npc")
dev.off()

#################################################################################################
#### Supplementary Information ####
#### Supplementary Figures ####
load("m1_mcmc_th50_it53K.R")
load("m2_mcmc_th50_it53K.R")
load("m1_CAC_mcmc_th50_it53K.R")
load("m2_CAC_mcmc_th50_it53K.R")
load("m1_ATACR_mcmc_th50_it53K.R")
load("m2_ATACR_mcmc_th50_it53K.R")

##### Fig.S -- show Prov and dbMEM effects (temporal autocorr) ####
#### Year Model ####
#### PC1_MEM Graph ####
PC1_T_MEM<-data.table(Source=c("MEM3","MEM5","MEM6","MEM7","MEM8","MEM9",
                               "MEM12","MEM13","MEM15","MEM16","MEM20"),
                      mean.PC1=NA,up.PC1=NA,low.PC1=NA)

PC1_T_MEM$mean.PC1<-summary(m1_mcmc)$sol[c("MEM3","MEM5","MEM6","MEM7","MEM8","MEM9",
                                           "MEM12","MEM13","MEM15","MEM16","MEM20"),1]

PC1_T_MEM$up.PC1<-summary(m1_mcmc)$sol[c("MEM3","MEM5","MEM6","MEM7","MEM8","MEM9",
                                         "MEM12","MEM13","MEM15","MEM16","MEM20"),3]

PC1_T_MEM$low.PC1<-summary(m1_mcmc)$sol[c("MEM3","MEM5","MEM6","MEM7","MEM8","MEM9",
                                          "MEM12","MEM13","MEM15","MEM16","MEM20"),2]


PC1_T_MEM$Source<-factor(PC1_T_MEM$Source,levels=rev(c("MEM3","MEM5","MEM6","MEM7","MEM8","MEM9",
                                                       "MEM12","MEM13","MEM15","MEM16","MEM20")))

PC1_MEM<-ggplot(PC1_T_MEM,aes(x=mean.PC1,xmin=low.PC1,xmax=up.PC1,y=Source))+
  geom_vline(aes(xintercept=0),linetype="dashed",colour="grey")+ 
  geom_point(position=position_dodge(0.4),col="royalblue")+
  geom_errorbar(position=position_dodge(0.4),width=0.2,col="royalblue")+
  scale_color_discrete(name="Model")+
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank())+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  xlab("")+ylab("")
PC1_MEM

#### PC2_MEM Graph ####
PC2_T_MEM<-data.table(Source=c("MEM3","MEM4","MEM5","MEM6","MEM9",
                               "MEM15","MEM20","MEM22","MEM23"),
                      mean.PC2=NA,up.PC2=NA,low.PC2=NA)

PC2_T_MEM$mean.PC2<-summary(m2_mcmc)$sol[c("MEM3","MEM4","MEM5","MEM6","MEM9",
                                           "MEM15","MEM20","MEM22","MEM23"),1]

PC2_T_MEM$up.PC2<-summary(m2_mcmc)$sol[c("MEM3","MEM4","MEM5","MEM6","MEM9",
                                         "MEM15","MEM20","MEM22","MEM23"),3]

PC2_T_MEM$low.PC2<-summary(m2_mcmc)$sol[c("MEM3","MEM4","MEM5","MEM6","MEM9",
                                          "MEM15","MEM20","MEM22","MEM23"),2]


PC2_T_MEM$Source<-factor(PC2_T_MEM$Source,levels=rev(c("MEM3","MEM4","MEM5","MEM6","MEM9",
                                                       "MEM15","MEM20","MEM22","MEM23")))

PC2_MEM<-ggplot(PC2_T_MEM,aes(x=mean.PC2,xmin=low.PC2,xmax=up.PC2,y=Source))+
  geom_vline(aes(xintercept=0),linetype="dashed",colour="grey")+ 
  geom_point(position=position_dodge(0.4),col="maroon")+
  geom_errorbar(position=position_dodge(0.4),width=0.2,col="maroon")+
  scale_color_discrete(name="Model")+
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank())+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  xlab("")+ylab("")
PC2_MEM

#### ATAChangeRate Model ####
#### PC1_MEM_CR Graph ####
PC1_T_MEM_CR<-data.table(Source=c("MEM3","MEM5","MEM6","MEM7","MEM8","MEM9",
                                  "MEM12","MEM13","MEM15","MEM16","MEM20"),
                         mean.PC1=NA,up.PC1=NA,low.PC1=NA)

PC1_T_MEM_CR$mean.PC1<-summary(m1_ATACR_mcmc)$sol[c("MEM3","MEM5","MEM6","MEM7","MEM8","MEM9",
                                                    "MEM12","MEM13","MEM15","MEM16","MEM20"),1]

PC1_T_MEM_CR$up.PC1<-summary(m1_ATACR_mcmc)$sol[c("MEM3","MEM5","MEM6","MEM7","MEM8","MEM9",
                                                  "MEM12","MEM13","MEM15","MEM16","MEM20"),3]

PC1_T_MEM_CR$low.PC1<-summary(m1_ATACR_mcmc)$sol[c("MEM3","MEM5","MEM6","MEM7","MEM8","MEM9",
                                                   "MEM12","MEM13","MEM15","MEM16","MEM20"),2]


PC1_T_MEM_CR$Source<-factor(PC1_T_MEM_CR$Source,levels=rev(c("MEM3","MEM5","MEM6","MEM7","MEM8","MEM9",
                                                             "MEM12","MEM13","MEM15","MEM16","MEM20")))

PC1_T_CR_MEM<-ggplot(PC1_T_MEM_CR,aes(x=mean.PC1,xmin=low.PC1,xmax=up.PC1,y=Source))+
  geom_vline(aes(xintercept=0),linetype="dashed",colour="grey")+ 
  geom_point(position=position_dodge(0.4),col="turquoise4")+
  geom_errorbar(position=position_dodge(0.4),width=0.2,col="turquoise4")+
  scale_color_discrete(name="Model")+
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank())+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  xlab("")+ylab("")
PC1_T_CR_MEM

#### PC2_T_CR_MEM_CR Graph ####
PC2_T_MEM_CR<-data.table(Source=c("MEM3","MEM4","MEM5","MEM6","MEM9",
                                  "MEM15","MEM20","MEM22","MEM23"),
                         mean.PC2=NA,up.PC2=NA,low.PC2=NA)

PC2_T_MEM_CR$mean.PC2<-summary(m2_ATACR_mcmc)$sol[c("MEM3","MEM4","MEM5","MEM6","MEM9",
                                                    "MEM15","MEM20","MEM22","MEM23"),1]

PC2_T_MEM_CR$up.PC2<-summary(m2_ATACR_mcmc)$sol[c("MEM3","MEM4","MEM5","MEM6","MEM9",
                                                  "MEM15","MEM20","MEM22","MEM23"),3]

PC2_T_MEM_CR$low.PC2<-summary(m2_ATACR_mcmc)$sol[c("MEM3","MEM4","MEM5","MEM6","MEM9",
                                                   "MEM15","MEM20","MEM22","MEM23"),2]


PC2_T_MEM_CR$Source<-factor(PC2_T_MEM_CR$Source,levels=rev(c("MEM3","MEM4","MEM5","MEM6","MEM9",
                                                             "MEM15","MEM20","MEM22","MEM23")))

PC2_T_CR_MEM<-ggplot(PC2_T_MEM_CR,aes(x=mean.PC2,xmin=low.PC2,xmax=up.PC2,y=Source))+
  geom_vline(aes(xintercept=0),linetype="dashed",colour="grey")+ 
  geom_point(position=position_dodge(0.4),col="violetred")+
  geom_errorbar(position=position_dodge(0.4),width=0.2,col="violetred")+
  scale_color_discrete(name="Model")+
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank())+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  xlab("")+ylab("")
PC2_T_CR_MEM

#### Climate Model ####
#### PC1_MEM_CAC Graph ####
PC1_T_MEM_CAC<-data.table(Source=c("MEM3","MEM5","MEM6","MEM7","MEM8","MEM9",
                                   "MEM12","MEM13","MEM15","MEM16","MEM20"),
                          mean.PC1=NA,up.PC1=NA,low.PC1=NA)

PC1_T_MEM_CAC$mean.PC1<-summary(m1_CAC_mcmc)$sol[c("MEM3","MEM5","MEM6","MEM7","MEM8","MEM9",
                                                   "MEM12","MEM13","MEM15","MEM16","MEM20"),1]

PC1_T_MEM_CAC$up.PC1<-summary(m1_CAC_mcmc)$sol[c("MEM3","MEM5","MEM6","MEM7","MEM8","MEM9",
                                                 "MEM12","MEM13","MEM15","MEM16","MEM20"),3]

PC1_T_MEM_CAC$low.PC1<-summary(m1_CAC_mcmc)$sol[c("MEM3","MEM5","MEM6","MEM7","MEM8","MEM9",
                                                  "MEM12","MEM13","MEM15","MEM16","MEM20"),2]


PC1_T_MEM_CAC$Source<-factor(PC1_T_MEM_CAC$Source,levels=rev(c("MEM3","MEM5","MEM6","MEM7","MEM8","MEM9",
                                                               "MEM12","MEM13","MEM15","MEM16","MEM20")))

PC1_T_CAC_MEM<-ggplot(PC1_T_MEM_CAC,aes(x=mean.PC1,xmin=low.PC1,xmax=up.PC1,y=Source))+
  geom_vline(aes(xintercept=0),linetype="dashed",colour="grey")+ 
  geom_point(position=position_dodge(0.4),col="skyblue2")+
  geom_errorbar(position=position_dodge(0.4),width=0.2,col="skyblue2")+
  scale_color_discrete(name="Model")+
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank())+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  xlab(expression(paste("Coefficient estimate")))+ylab("")
PC1_T_CAC_MEM

#### PC2_T_CAC_MEM_CAC Graph ####
PC2_T_MEM_CAC<-data.table(Source=c("MEM3","MEM4","MEM5","MEM6","MEM9",
                                   "MEM15","MEM20","MEM22","MEM23"),
                          mean.PC2=NA,up.PC2=NA,low.PC2=NA)

PC2_T_MEM_CAC$mean.PC2<-summary(m2_CAC_mcmc)$sol[c("MEM3","MEM4","MEM5","MEM6","MEM9",
                                                   "MEM15","MEM20","MEM22","MEM23"),1]

PC2_T_MEM_CAC$up.PC2<-summary(m2_CAC_mcmc)$sol[c("MEM3","MEM4","MEM5","MEM6","MEM9",
                                                 "MEM15","MEM20","MEM22","MEM23"),3]

PC2_T_MEM_CAC$low.PC2<-summary(m2_CAC_mcmc)$sol[c("MEM3","MEM4","MEM5","MEM6","MEM9",
                                                  "MEM15","MEM20","MEM22","MEM23"),2]


PC2_T_MEM_CAC$Source<-factor(PC2_T_MEM_CAC$Source,levels=rev(c("MEM3","MEM4","MEM5","MEM6","MEM9",
                                                               "MEM15","MEM20","MEM22","MEM23")))

PC2_T_CAC_MEM<-ggplot(PC2_T_MEM_CAC,aes(x=mean.PC2,xmin=low.PC2,xmax=up.PC2,y=Source))+
  geom_vline(aes(xintercept=0),linetype="dashed",colour="grey")+ 
  geom_point(position=position_dodge(0.4),col="violet")+
  geom_errorbar(position=position_dodge(0.4),width=0.2,col="violet")+
  scale_color_discrete(name="Model")+
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank())+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  xlab(expression(paste("Coefficient estimate")))+ylab("")
PC2_T_CAC_MEM

#### Bind ####
maxWidth = unit.pmax(PC1_MEM$widths[2:3],PC2_MEM$widths[2:3],
                     PC1_T_CAC_MEM$widths[2:3],PC2_T_CAC_MEM$widths[2:3],
                     PC1_T_CR_MEM$widths[2:3],PC2_T_CR_MEM$widths[2:3],)

PC1_MEM$widths[2:3] <- maxWidth
PC2_MEM$widths[2:3] <- maxWidth
PC1_T_CAC_MEM$widths[2:3] <- maxWidth
PC2_T_CAC_MEM$widths[2:3] <- maxWidth
PC1_T_CR_MEM$widths[2:3] <- maxWidth
PC2_T_CR_MEM$widths[2:3] <- maxWidth

p1<-ggplot_gtable(ggplot_build(PC1_MEM))
p2<-ggplot_gtable(ggplot_build(PC2_MEM))
p1_CAC<-ggplot_gtable(ggplot_build(PC1_T_CAC_MEM))
p2_CAC<-ggplot_gtable(ggplot_build(PC2_T_CAC_MEM))
p1_CR<-ggplot_gtable(ggplot_build(PC1_T_CR_MEM))
p2_CR<-ggplot_gtable(ggplot_build(PC2_T_CR_MEM))

tiff("FigS_MCMCglmm_MEM_Effect_Size_Year_Climate.tiff",width=2500,height=2800,res=300,compression="lzw")
grid.draw(cbind(rbind(p1,p1_CR,p1_CAC),rbind(p2,p2_CR,p2_CAC),size="last"))
grid.text(expression(paste("a: Year Model (",CWM[PC1],")")),x=unit(0.31,"npc"),y=unit(0.98,"npc"),gp=gpar(fontsize=10,font=2))
grid.text(expression(paste("b: Year Model (",CWM[PC2],")")),x=unit(0.81,"npc"),y=unit(0.98,"npc"),gp=gpar(fontsize=10,font=2))
grid.text(expression(paste("c: Climate Change Rate Model (",CWM[PC1],")")),x=unit(0.31,"npc"),y=unit(0.648,"npc"),gp=gpar(fontsize=10,font=2))
grid.text(expression(paste("d: Climate Change Rate Model (",CWM[PC2],")")),x=unit(0.81,"npc"),y=unit(0.648,"npc"),gp=gpar(fontsize=10,font=2))
grid.text(expression(paste("e: Climate Simultaneous Model (",CWM[PC1],")")),x=unit(0.31,"npc"),y=unit(0.317,"npc"),gp=gpar(fontsize=10,font=2))
grid.text(expression(paste("f: Climate Simultaneous Model (",CWM[PC2],")")),x=unit(0.81,"npc"),y=unit(0.317,"npc"),gp=gpar(fontsize=10,font=2))

dev.off()

#### Fig.S Model with ATA-ACMIA-ChangeRate ####
##### MCMC #####
nsamp <- 1000
THIN <- 50
BURNIN <- 3000
NITT <- BURNIN + THIN*nsamp

#PC1 Model
m1_ATACR_mcmc<-MCMCglmm(PC1~PS+Prov+
                          MEM3+MEM5+MEM6+MEM7+MEM8+MEM9+MEM12+MEM13+MEM15+MEM16+MEM20+
                          sqrtSA+Y+ACMIAChangeRate+ATAChangeRate+
                          sqrtSA:Y+sqrtSA:ACMIAChangeRate+sqrtSA:ATAChangeRate+
                          Y:ACMIAChangeRate+Y:ATAChangeRate+
                          ACMIAChangeRate:ATAChangeRate,
                        random = ~PLOT_ID, 
                        data = can,
                        nitt = NITT, thin = THIN, burnin = BURNIN)

#save(m1_ATACR_mcmc,file="m1_ATACR_mcmc_th50_it53K.R")
load("m1_ATACR_mcmc_th50_it53K.R")

summary(m1_ATACR_mcmc$Sol)
summary(m1_ATACR_mcmc)$solutions

#PC2 Model
m2_ATACR_mcmc<-MCMCglmm(PC2~PS+Prov+
                          MEM3+MEM4+MEM5+MEM6+MEM9+MEM15+MEM20+MEM22+MEM23+
                          sqrtSA+Y+ACMIAChangeRate+ATAChangeRate+
                          sqrtSA:Y+sqrtSA:ACMIAChangeRate+sqrtSA:ATAChangeRate+
                          Y:ACMIAChangeRate+Y:ATAChangeRate+
                          ACMIAChangeRate:ATAChangeRate,
                        random = ~PLOT_ID, 
                        data = can,
                        nitt = NITT, thin = THIN, burnin = BURNIN)

#save(m2_ATACR_mcmc,file="m2_ATACR_mcmc_th50_it53K.R")
load("m2_ATACR_mcmc_th50_it53K.R")

summary(m2_ATACR_mcmc$Sol)
summary(m2_ATACR_mcmc)$solutions

############## Effect size ##############
#### PC1 Graph ####
PC1_T<-data.table(Source=c("Intercept","PS","f(SA)","Year","ACMIAChangeRate","ATAChangeRate",
                           "f(SA):Year","f(SA):ACMIAChangeRate","f(SA):ATAChangeRate","Year:ACMIAChangeRate",
                           "Year:ATAChangeRate","ACMIAChangeRate:ATAChangeRate"),
                  mean.PC1=NA,up.PC1=NA,low.PC1=NA)

PC1_T$mean.PC1<-summary(m1_ATACR_mcmc)$sol[c("(Intercept)","PS","sqrtSA","Y","ACMIAChangeRate","ATAChangeRate",
                                             "sqrtSA:Y","sqrtSA:ACMIAChangeRate","sqrtSA:ATAChangeRate","Y:ACMIAChangeRate",
                                             "Y:ATAChangeRate","ACMIAChangeRate:ATAChangeRate"),1]

PC1_T$up.PC1<-summary(m1_ATACR_mcmc)$sol[c("(Intercept)","PS","sqrtSA","Y","ACMIAChangeRate","ATAChangeRate",
                                           "sqrtSA:Y","sqrtSA:ACMIAChangeRate","sqrtSA:ATAChangeRate","Y:ACMIAChangeRate",
                                           "Y:ATAChangeRate","ACMIAChangeRate:ATAChangeRate"),3]

PC1_T$low.PC1<-summary(m1_ATACR_mcmc)$sol[c("(Intercept)","PS","sqrtSA","Y","ACMIAChangeRate","ATAChangeRate",
                                            "sqrtSA:Y","sqrtSA:ACMIAChangeRate","sqrtSA:ATAChangeRate","Y:ACMIAChangeRate",
                                            "Y:ATAChangeRate","ACMIAChangeRate:ATAChangeRate"),2]


PC1_T$Source<-factor(PC1_T$Source,levels=rev(c("Intercept","PS","f(SA)","Year","ACMIAChangeRate","ATAChangeRate",
                                               "f(SA):Year","f(SA):ACMIAChangeRate","f(SA):ATAChangeRate","Year:ACMIAChangeRate",
                                               "Year:ATAChangeRate","ACMIAChangeRate:ATAChangeRate")))

PC1<-ggplot(PC1_T[Source!="Intercept"],aes(x=mean.PC1,xmin=low.PC1,xmax=up.PC1,y=Source))+
  geom_vline(aes(xintercept=0),linetype="dashed",colour="grey")+ 
  geom_point(position=position_dodge(0.4),col="turquoise4")+
  geom_errorbar(position=position_dodge(0.4),width=0.2,col="turquoise4")+
  scale_color_discrete(name="Model")+
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank())+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  xlab(expression(paste("Coefficient estimate")))+ylab("")
PC1

#### PC2 Graph ####
PC2_T<-data.table(Source=c("Intercept","PS","f(SA)","Year","ACMIAChangeRate","ATAChangeRate",
                           "f(SA):Year","f(SA):ACMIAChangeRate","f(SA):ATAChangeRate","Year:ACMIAChangeRate",
                           "Year:ATAChangeRate","ACMIAChangeRate:ATAChangeRate"),
                  mean.PC2=NA,up.PC2=NA,low.PC2=NA)

PC2_T$mean.PC2<-summary(m2_ATACR_mcmc)$sol[c("(Intercept)","PS","sqrtSA","Y","ACMIAChangeRate","ATAChangeRate",
                                             "sqrtSA:Y","sqrtSA:ACMIAChangeRate","sqrtSA:ATAChangeRate","Y:ACMIAChangeRate",
                                             "Y:ATAChangeRate","ACMIAChangeRate:ATAChangeRate"),1]

PC2_T$up.PC2<-summary(m2_ATACR_mcmc)$sol[c("(Intercept)","PS","sqrtSA","Y","ACMIAChangeRate","ATAChangeRate",
                                           "sqrtSA:Y","sqrtSA:ACMIAChangeRate","sqrtSA:ATAChangeRate","Y:ACMIAChangeRate",
                                           "Y:ATAChangeRate","ACMIAChangeRate:ATAChangeRate"),3]

PC2_T$low.PC2<-summary(m2_ATACR_mcmc)$sol[c("(Intercept)","PS","sqrtSA","Y","ACMIAChangeRate","ATAChangeRate",
                                            "sqrtSA:Y","sqrtSA:ACMIAChangeRate","sqrtSA:ATAChangeRate","Y:ACMIAChangeRate",
                                            "Y:ATAChangeRate","ACMIAChangeRate:ATAChangeRate"),2]


PC2_T$Source<-factor(PC2_T$Source,levels=rev(c("Intercept","PS","f(SA)","Year","ACMIAChangeRate","ATAChangeRate",
                                               "f(SA):Year","f(SA):ACMIAChangeRate","f(SA):ATAChangeRate","Year:ACMIAChangeRate",
                                               "Year:ATAChangeRate","ACMIAChangeRate:ATAChangeRate")))

PC2<-ggplot(PC2_T[Source!="Intercept"],aes(x=mean.PC2,xmin=low.PC2,xmax=up.PC2,y=Source))+
  geom_vline(aes(xintercept=0),linetype="dashed",colour="grey")+ 
  geom_point(position=position_dodge(0.4),col="violetred")+
  geom_errorbar(position=position_dodge(0.4),width=0.2,col="violetred")+
  scale_color_discrete(name="Model")+
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank())+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  xlab(expression(paste("Coefficient estimate")))+ylab("")
PC2

#### Bind ####
maxWidth = unit.pmax(PC1$widths[2:3],PC2$widths[2:3])
PC1$widths[2:3] <- maxWidth
PC2$widths[2:3] <- maxWidth

p1<-ggplot_gtable(ggplot_build(PC1))
p2<-ggplot_gtable(ggplot_build(PC2))

tiff("FigS_MCMCglmm_Effect_Size_ATAChangeRate.tiff",width=3800,height=2000,res=300,compression="lzw")
grid.draw(cbind(p1,p2,size="last"))
grid.text(expression(paste("a (",CWM[PC1],")")),x=unit(0.23,"npc"),y=unit(0.96,"npc"),gp=gpar(fontsize=12,font=2))
grid.text(expression(paste("b (",CWM[PC2],")")),x=unit(0.73,"npc"),y=unit(0.96,"npc"),gp=gpar(fontsize=12,font=2))

dev.off()

############## Interaction ##############
#### PC1 ####
coefmean<-summary(m1_ATACR_mcmc)$sol[,1]
coefmean_Int<-mean(c(coefmean["(Intercept)"],
                     coefmean["(Intercept)"]+coefmean["ProvAC"],
                     coefmean["(Intercept)"]+coefmean["ProvBC"],
                     coefmean["(Intercept)"]+coefmean["ProvMB"],
                     coefmean["(Intercept)"]+coefmean["ProvNFImm"],
                     coefmean["(Intercept)"]+coefmean["ProvNFMat"],
                     coefmean["(Intercept)"]+coefmean["ProvNS"],
                     coefmean["(Intercept)"]+coefmean["ProvON"],
                     coefmean["(Intercept)"]+coefmean["ProvQC"],
                     coefmean["(Intercept)"]+coefmean["ProvSK"]))

coefCIlow<-summary(m1_ATACR_mcmc)$sol[,2]
coefCIlow_Int<-mean(c(coefCIlow["(Intercept)"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvAC"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvBC"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvMB"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvNFImm"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvNFMat"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvNS"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvON"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvQC"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvSK"]))

coefCIup<-summary(m1_ATACR_mcmc)$sol[,3]
coefCIup_Int<-mean(c(coefCIup["(Intercept)"],
                     coefCIup["(Intercept)"]+coefCIup["ProvAC"],
                     coefCIup["(Intercept)"]+coefCIup["ProvBC"],
                     coefCIup["(Intercept)"]+coefCIup["ProvMB"],
                     coefCIup["(Intercept)"]+coefCIup["ProvNFImm"],
                     coefCIup["(Intercept)"]+coefCIup["ProvNFMat"],
                     coefCIup["(Intercept)"]+coefCIup["ProvNS"],
                     coefCIup["(Intercept)"]+coefCIup["ProvON"],
                     coefCIup["(Intercept)"]+coefCIup["ProvQC"],
                     coefCIup["(Intercept)"]+coefCIup["ProvSK"]))

#### ACMIAChangeRate ####
coef_ACMIAChangeRate<-function(x){
  ACMIAChangeRate=x
  data.table(mean=coefmean_Int+(coefmean["Y"]*(seq(min(can$Y),max(can$Y),length=600)))+(coefmean["ACMIAChangeRate"]*ACMIAChangeRate)+
               (coefmean["Y:ACMIAChangeRate"]*ACMIAChangeRate*(seq(min(can$Y),max(can$Y),length=600))),
             up=sapply(seq(min(can$Y),max(can$Y),length=600),function(x,r=ACMIAChangeRate){
               coefCIup_Int+(coefCIup["Y"]*x)+(coefCIup["ACMIAChangeRate"]*r)+(coefCIup["Y:ACMIAChangeRate"]*x*r)}),
             low=sapply(seq(min(can$Y),max(can$Y),length=600),function(x,r=ACMIAChangeRate){
               coefCIlow_Int+(coefCIlow["Y"]*x)+(coefCIlow["ACMIAChangeRate"]*r)+(coefCIlow["Y:ACMIAChangeRate"]*x*r)}),
             Y=seq(min(can$Y),max(can$Y),length=600),
             FinY=(seq(min(can$Y),max(can$Y),length=600))*sd(can$FinY)+mean(can$FinY),
             ACMIAChangeRaterage=ACMIAChangeRate)
}

to_graph<-adply(round(c(seq(quantile(can$ACMIAChangeRate,0.05),quantile(can$ACMIAChangeRate,0.95),length=4),0),2),
                .margins=1,.fun=function(x)coef_ACMIAChangeRate(x))
to_graph$ACMIAChangeRaterage<-as.factor(to_graph$ACMIAChangeRaterage)

round(c(seq(quantile(can$ACMIAChangeRate1,0.05),quantile(can$ACMIAChangeRate1,0.95),length=4),mean(can$ACMIAChangeRate1)),1)

PC1_ACMIAChangeRate<-ggplot(to_graph,aes(x=FinY,y=mean,col=ACMIAChangeRaterage,linetype=ACMIAChangeRaterage))+
  theme_classic()+
  geom_ribbon(aes(x=FinY,ymin=low,ymax=up,group=ACMIAChangeRaterage),fill="royalblue",col=NA,alpha=0.05)+
  geom_line(size=1.1)+
  scale_linetype_manual(values = c("solid","solid","solid","solid","solid"),guide=F)+
  scale_colour_manual(values=c("lightskyblue1","skyblue2","black","royalblue1","royalblue4"),
                      name="",
                      labels=c("-1.43"="-0.3", "-0.44"="-0.1","0.54"="0.1","1.52"="0.3","0"="Mean (0.0)"))+
  xlab("")+
  ylab(expression(paste("Conifers    (",CWM[PC1],")    DB")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x=element_blank(), axis.line.y = element_line())#+
#ylim(c(-2.4,0.6))
PC1_ACMIAChangeRate

j1 <- ggplotGrob(PC1_ACMIAChangeRate)

#### ATAChangeRate ####
coef_ATAChangeRate<-function(x){
  ATAChangeRate=x
  data.table(mean=coefmean_Int+(coefmean["Y"]*(seq(min(can$Y),max(can$Y),length=600)))+(coefmean["ATAChangeRate"]*ATAChangeRate)+
               (coefmean["Y:ATAChangeRate"]*ATAChangeRate*(seq(min(can$Y),max(can$Y),length=600))),
             up=sapply(seq(min(can$Y),max(can$Y),length=600),function(x,r=ATAChangeRate){
               coefCIup_Int+(coefCIup["Y"]*x)+(coefCIup["ATAChangeRate"]*r)+(coefCIup["Y:ATAChangeRate"]*x*r)}),
             low=sapply(seq(min(can$Y),max(can$Y),length=600),function(x,r=ATAChangeRate){
               coefCIlow_Int+(coefCIlow["Y"]*x)+(coefCIlow["ATAChangeRate"]*r)+(coefCIlow["Y:ATAChangeRate"]*x*r)}),
             Y=seq(min(can$Y),max(can$Y),length=600),
             FinY=(seq(min(can$Y),max(can$Y),length=600))*sd(can$FinY)+mean(can$FinY),
             ATAChangeRaterage=ATAChangeRate)
}

to_graph<-adply(round(c(seq(quantile(can$ATAChangeRate,0.05),quantile(can$ATAChangeRate,0.95),length=4),0),2),
                .margins=1,.fun=function(x)coef_ATAChangeRate(x))
to_graph$ATAChangeRaterage<-as.factor(to_graph$ATAChangeRaterage)

round(c(seq(quantile(can$ATAChangeRate1,0.05),quantile(can$ATAChangeRate1,0.95),length=4),mean(can$ATAChangeRate1)),2)

PC1_ATAChangeRate<-ggplot(to_graph,aes(x=FinY,y=mean,col=ATAChangeRaterage,linetype=ATAChangeRaterage))+
  theme_classic()+
  geom_ribbon(aes(x=FinY,ymin=low,ymax=up,group=ATAChangeRaterage),fill="royalblue",col=NA,alpha=0.05)+
  geom_line(size=1.1)+
  scale_linetype_manual(values = c("solid","solid","solid","solid","solid"),guide=F)+
  scale_colour_manual(values=c("steelblue","olivedrab","black","goldenrod3","hotpink3"),
                      name="",
                      labels=c("-1.3"="0.00", "-0.14"="0.02","1.02"="0.03","2.18"="0.04","0"="Mean (0.02)"))+
  xlab("")+
  ylab(expression(paste("Conifers    (",CWM[PC1],")    DB")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line())#+
#ylim(c(-1.6,1.1))
PC1_ATAChangeRate

k1 <- ggplotGrob(PC1_ATAChangeRate)

#### PC2 ####
coefmean<-summary(m2_ATACR_mcmc)$sol[,1]
coefmean_Int<-mean(c(coefmean["(Intercept)"],
                     coefmean["(Intercept)"]+coefmean["ProvAC"],
                     coefmean["(Intercept)"]+coefmean["ProvBC"],
                     coefmean["(Intercept)"]+coefmean["ProvMB"],
                     coefmean["(Intercept)"]+coefmean["ProvNFImm"],
                     coefmean["(Intercept)"]+coefmean["ProvNFMat"],
                     coefmean["(Intercept)"]+coefmean["ProvNS"],
                     coefmean["(Intercept)"]+coefmean["ProvON"],
                     coefmean["(Intercept)"]+coefmean["ProvQC"],
                     coefmean["(Intercept)"]+coefmean["ProvSK"]))

coefCIlow<-summary(m2_ATACR_mcmc)$sol[,2]
coefCIlow_Int<-mean(c(coefCIlow["(Intercept)"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvAC"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvBC"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvMB"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvNFImm"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvNFMat"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvNS"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvON"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvQC"],
                      coefCIlow["(Intercept)"]+coefCIlow["ProvSK"]))

coefCIup<-summary(m2_ATACR_mcmc)$sol[,3]
coefCIup_Int<-mean(c(coefCIup["(Intercept)"],
                     coefCIup["(Intercept)"]+coefCIup["ProvAC"],
                     coefCIup["(Intercept)"]+coefCIup["ProvBC"],
                     coefCIup["(Intercept)"]+coefCIup["ProvMB"],
                     coefCIup["(Intercept)"]+coefCIup["ProvNFImm"],
                     coefCIup["(Intercept)"]+coefCIup["ProvNFMat"],
                     coefCIup["(Intercept)"]+coefCIup["ProvNS"],
                     coefCIup["(Intercept)"]+coefCIup["ProvON"],
                     coefCIup["(Intercept)"]+coefCIup["ProvQC"],
                     coefCIup["(Intercept)"]+coefCIup["ProvSK"]))

#### ACMIAChangeRate ####
coef_ACMIAChangeRate<-function(x){
  ACMIAChangeRate=x
  data.table(mean=coefmean_Int+(coefmean["Y"]*(seq(min(can$Y),max(can$Y),length=600)))+(coefmean["ACMIAChangeRate"]*ACMIAChangeRate)+
               (coefmean["Y:ACMIAChangeRate"]*ACMIAChangeRate*(seq(min(can$Y),max(can$Y),length=600))),
             up=sapply(seq(min(can$Y),max(can$Y),length=600),function(x,r=ACMIAChangeRate){
               coefCIup_Int+(coefCIup["Y"]*x)+(coefCIup["ACMIAChangeRate"]*r)+(coefCIup["Y:ACMIAChangeRate"]*x*r)}),
             low=sapply(seq(min(can$Y),max(can$Y),length=600),function(x,r=ACMIAChangeRate){
               coefCIlow_Int+(coefCIlow["Y"]*x)+(coefCIlow["ACMIAChangeRate"]*r)+(coefCIlow["Y:ACMIAChangeRate"]*x*r)}),
             Y=seq(min(can$Y),max(can$Y),length=600),
             FinY=(seq(min(can$Y),max(can$Y),length=600))*sd(can$FinY)+mean(can$FinY),
             ACMIAChangeRaterage=ACMIAChangeRate)
}

to_graph<-adply(round(c(seq(quantile(can$ACMIAChangeRate,0.05),quantile(can$ACMIAChangeRate,0.95),length=4),0),2),
                .margins=1,.fun=function(x)coef_ACMIAChangeRate(x))
to_graph$ACMIAChangeRaterage<-as.factor(to_graph$ACMIAChangeRaterage)

round(c(seq(quantile(can$ACMIAChangeRate1,0.05),quantile(can$ACMIAChangeRate1,0.95),length=4),mean(can$ACMIAChangeRate1)),1)

PC2_ACMIAChangeRate<-ggplot(to_graph,aes(x=FinY,y=mean,col=ACMIAChangeRaterage,linetype=ACMIAChangeRaterage))+
  theme_classic()+
  geom_ribbon(aes(x=FinY,ymin=low,ymax=up,group=ACMIAChangeRaterage),fill="royalblue",col=NA,alpha=0.05)+
  geom_line(size=1.1)+
  scale_linetype_manual(values = c("solid","solid","solid","solid","solid"),guide=F)+
  scale_colour_manual(values=c("lightskyblue1","skyblue2","black","royalblue1","royalblue4"),
                      name="",
                      labels=c("-1.39"="1.0", "-0.53"="35.6","0.33"="70.2","1.2"="104.8","0"="Mean (56.8)"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab("Year")+
  ylab(expression(paste("Lower DT    ","(CW",M[PC2],")    Higher DT")))+
  #ylab(expression(paste("Drought tolerance"," (",-1%*%CWM[PC2],")")))+
  theme(legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))+
  ylim(c(-0.5,1.0))
PC2_ACMIAChangeRate

j2 <- ggplotGrob(PC2_ACMIAChangeRate)

#### ATAChangeRate ####
coef_ATAChangeRate<-function(x){
  ATAChangeRate=x
  data.table(mean=coefmean_Int+(coefmean["Y"]*(seq(min(can$Y),max(can$Y),length=600)))+(coefmean["ATAChangeRate"]*ATAChangeRate)+
               (coefmean["Y:ATAChangeRate"]*ATAChangeRate*(seq(min(can$Y),max(can$Y),length=600))),
             up=sapply(seq(min(can$Y),max(can$Y),length=600),function(x,r=ATAChangeRate){
               coefCIup_Int+(coefCIup["Y"]*x)+(coefCIup["ATAChangeRate"]*r)+(coefCIup["Y:ATAChangeRate"]*x*r)}),
             low=sapply(seq(min(can$Y),max(can$Y),length=600),function(x,r=ATAChangeRate){
               coefCIlow_Int+(coefCIlow["Y"]*x)+(coefCIlow["ATAChangeRate"]*r)+(coefCIlow["Y:ATAChangeRate"]*x*r)}),
             Y=seq(min(can$Y),max(can$Y),length=600),
             FinY=(seq(min(can$Y),max(can$Y),length=600))*sd(can$FinY)+mean(can$FinY),
             ATAChangeRaterage=ATAChangeRate)
}

to_graph<-adply(round(c(seq(quantile(can$ATAChangeRate,0.05),quantile(can$ATAChangeRate,0.95),length=4),0),2),
                .margins=1,.fun=function(x)coef_ATAChangeRate(x))
to_graph$ATAChangeRaterage<-as.factor(to_graph$ATAChangeRaterage)

round(c(seq(quantile(can$ATAChangeRate1,0.05),quantile(can$ATAChangeRate1,0.95),length=4),mean(can$ATAChangeRate1)),1)

PC2_ATAChangeRate<-ggplot(to_graph,aes(x=FinY,y=mean,col=ATAChangeRaterage,linetype=ATAChangeRaterage))+
  theme_classic()+
  geom_ribbon(aes(x=FinY,ymin=low,ymax=up,group=ATAChangeRaterage),fill="royalblue",col=NA,alpha=0.05)+
  geom_line(size=1.1)+
  scale_linetype_manual(values = c("solid","solid","solid","solid","solid"),guide=F)+
  scale_colour_manual(values=c("steelblue","olivedrab","black","goldenrod3","hotpink3"),
                      name="",
                      labels=c("-1.63"="-1.6", "-0.55"="1.3","0.53"="4.2","1.61"="7.1","0"="Mean (2.8)"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab("Year")+
  ylab(expression(paste("Lower DT    ","(CW",M[PC2],")    Higher DT")))+
  theme(legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))#+
#ylim(c(-0.2,1.2))
PC2_ATAChangeRate

k2 <- ggplotGrob(PC2_ATAChangeRate)

#### Bind figures ####
rbind_gtable_max <- function(...){
  gtl <- list(...)
  stopifnot(all(sapply(gtl, is.gtable)))
  bind2 <- function (x, y) 
  {
    stopifnot(ncol(x) == ncol(y))
    if (nrow(x) == 0) 
      return(y)
    if (nrow(y) == 0) 
      return(x)
    y$layout$t <- y$layout$t + nrow(x)
    y$layout$b <- y$layout$b + nrow(x)
    x$layout <- rbind(x$layout, y$layout)
    x$heights <- gtable:::insert.unit(x$heights, y$heights)
    x$rownames <- c(x$rownames, y$rownames)
    x$widths <- grid::unit.pmax(x$widths, y$widths)
    x$grobs <- append(x$grobs, y$grobs)
    x
  }
  
  Reduce(bind2, gtl)
}

maxWidth = unit.pmax(j1$widths[2:3], j2$widths[2:3])
j1$widths[2:3] <- maxWidth
j2$widths[2:3] <- maxWidth

maxWidth = unit.pmax(k1$widths[2:3], k2$widths[2:3])
k1$widths[2:3] <- maxWidth
k2$widths[2:3] <- maxWidth

tiff("FigS_ATACR_Mglmm_FinY_effects_by_ATAChangeRate.tiff",width=3200,height=2400,res=300,compression="lzw")
grid.draw(cbind(rbind(j1,j2,size="last"),rbind(k1,k2,size="last"),size="first"))
grid.text("a",x=unit(0.015,"npc"),y=unit(0.98,"npc"),gp=gpar(fontsize=14,font=2))
grid.text("b",x=unit(0.515,"npc"),y=unit(0.98,"npc"),gp=gpar(fontsize=14,font=2))

grid.text(expression(paste("ACMIA change rate")),x=unit(0.43,"npc"),y=unit(0.88,"npc"),gp=gpar(fontsize=11,font=2))
grid.text(expression(paste("(cm/yr)")),x=unit(0.43,"npc"),y=unit(0.85,"npc"),gp=gpar(fontsize=11,font=2))

grid.text(expression(paste("ATA change rate")),x=unit(0.93,"npc"),y=unit(0.88,"npc"),gp=gpar(fontsize=11,font=2))
grid.text(expression(paste("(",~degree*C,"/yr)")),x=unit(0.93,"npc"),y=unit(0.85,"npc"),gp=gpar(fontsize=11,font=2))

dev.off()

#### Fig.S Multi vs Individual climate model ####
#### Multi Model ####
load("m1_CAC_mcmc_th50_it53K.R")
load("m2_CAC_mcmc_th50_it53K.R")

nsamp <- 1000
THIN <- 50
BURNIN <- 3000
NITT <- BURNIN + THIN*nsamp

#### CO2 Model ####
m1_CO2_mcmc<-MCMCglmm(PC1~PS+Prov+
                        MEM3+MEM5+MEM6+MEM7+MEM8+MEM9+MEM12+MEM13+MEM15+MEM16+MEM20+
                        sqrtSA+CO2+CMIave+MATave+
                        sqrtSA:CO2+sqrtSA:CMIave+sqrtSA:MATave+CO2:CMIave+CO2:MATave+CMIave:MATave,
                      random = ~PLOT_ID,
                      data = can,
                      nitt = NITT, thin = THIN, burnin = BURNIN)

#save(m1_CO2_mcmc,file="m1_CO2_mcmc_th50_it53K.R")
load("m1_CO2_mcmc_th50_it53K.R")

m2_CO2_mcmc<-MCMCglmm(PC2~PS+Prov+
                        MEM3+MEM4+MEM5+MEM6+MEM9+MEM15+MEM20+MEM22+MEM23+
                        sqrtSA+CO2+CMIave+MATave+
                        sqrtSA:CO2+sqrtSA:CMIave+sqrtSA:MATave+CO2:CMIave+CO2:MATave+CMIave:MATave,
                      random = ~PLOT_ID,
                      data = can,
                      nitt = NITT, thin = THIN, burnin = BURNIN)

#save(m2_CO2_mcmc,file="m2_CO2_mcmc_th50_it53K.R")
load("m2_CO2_mcmc_th50_it53K.R")

#### ATA Model ####
m1_ATA_mcmc<-MCMCglmm(PC1~PS+Prov+
                        MEM3+MEM5+MEM6+MEM7+MEM8+MEM9+MEM12+MEM13+MEM15+MEM16+MEM20+
                        sqrtSA+ATA+CMIave+MATave+
                        sqrtSA:ATA+sqrtSA:CMIave+sqrtSA:MATave+ATA:CMIave+ATA:MATave+CMIave:MATave,
                      random = ~PLOT_ID,
                      data = can,
                      nitt = NITT, thin = THIN, burnin = BURNIN)

#save(m1_ATA_mcmc,file="m1_ATA_mcmc_th50_it53K.R")
load("m1_ATA_mcmc_th50_it53K.R")

m2_ATA_mcmc<-MCMCglmm(PC2~PS+Prov+
                        MEM3+MEM4+MEM5+MEM6+MEM9+MEM15+MEM20+MEM22+MEM23+
                        sqrtSA+ATA+CMIave+MATave+
                        sqrtSA:ATA+sqrtSA:CMIave+sqrtSA:MATave+ATA:CMIave+ATA:MATave+CMIave:MATave,
                      random = ~PLOT_ID,
                      data = can,
                      nitt = NITT, thin = THIN, burnin = BURNIN)

#save(m2_ATA_mcmc,file="m2_ATA_mcmc_th50_it53K.R")
load("m2_ATA_mcmc_th50_it53K.R")

#### ACMIA Model ####
m1_ACMIA_mcmc<-MCMCglmm(PC1~PS+Prov+
                          MEM3+MEM5+MEM6+MEM7+MEM8+MEM9+MEM12+MEM13+MEM15+MEM16+MEM20+
                          sqrtSA+ACMIA+CMIave+MATave+
                          sqrtSA:ACMIA+sqrtSA:CMIave+sqrtSA:MATave+ACMIA:CMIave+ACMIA:MATave+CMIave:MATave,
                        random = ~PLOT_ID,
                        data = can,
                        nitt = NITT, thin = THIN, burnin = BURNIN)

#save(m1_ACMIA_mcmc,file="m1_ACMIA_mcmc_th50_it53K.R")
load("m1_ACMIA_mcmc_th50_it53K.R")

m2_ACMIA_mcmc<-MCMCglmm(PC2~PS+Prov+
                          MEM3+MEM4+MEM5+MEM6+MEM9+MEM15+MEM20+MEM22+MEM23+
                          sqrtSA+ACMIA+CMIave+MATave+
                          sqrtSA:ACMIA+sqrtSA:CMIave+sqrtSA:MATave+ACMIA:CMIave+ACMIA:MATave+CMIave:MATave,
                        random = ~PLOT_ID,
                        data = can,
                        nitt = NITT, thin = THIN, burnin = BURNIN)

#save(m2_ACMIA_mcmc,file="m2_ACMIA_mcmc_th50_it53K.R")
load("m2_ACMIA_mcmc_th50_it53K.R")

###################
#### PC1 Graph ####
PC1_CAC_T<-data.table(Source=c("Intercept","PS","f(SA)","CO2","ATA","ACMIA","CMIave","MATave",
                               "f(SA):CO2","f(SA):ATA","f(SA):ACMIA",
                               "f(SA):CMIave","f(SA):MATave",
                               "CO2:CMIave","ATA:CMIave","ACMIA:CMIave",
                               "CO2:MATave","ATA:MATave","ACMIA:MATave",
                               "CMIave:MATave"),
                      mean.PC1=NA,up.PC1=NA,low.PC1=NA)

PC1_CAC_T$mean.PC1<-summary(m1_CAC_mcmc)$sol[c("(Intercept)","PS","sqrtSA","CO2","ATA","ACMIA","CMIave","MATave",
                                               "sqrtSA:CO2","sqrtSA:ATA","sqrtSA:ACMIA",
                                               "sqrtSA:CMIave","sqrtSA:MATave",
                                               "CO2:CMIave","ATA:CMIave","ACMIA:CMIave",
                                               "CO2:MATave","ATA:MATave","ACMIA:MATave",
                                               "CMIave:MATave"),1]

PC1_CAC_T$up.PC1<-summary(m1_CAC_mcmc)$sol[c("(Intercept)","PS","sqrtSA","CO2","ATA","ACMIA","CMIave","MATave",
                                             "sqrtSA:CO2","sqrtSA:ATA","sqrtSA:ACMIA",
                                             "sqrtSA:CMIave","sqrtSA:MATave",
                                             "CO2:CMIave","ATA:CMIave","ACMIA:CMIave",
                                             "CO2:MATave","ATA:MATave","ACMIA:MATave",
                                             "CMIave:MATave"),3]

PC1_CAC_T$low.PC1<-summary(m1_CAC_mcmc)$sol[c("(Intercept)","PS","sqrtSA","CO2","ATA","ACMIA","CMIave","MATave",
                                              "sqrtSA:CO2","sqrtSA:ATA","sqrtSA:ACMIA",
                                              "sqrtSA:CMIave","sqrtSA:MATave",
                                              "CO2:CMIave","ATA:CMIave","ACMIA:CMIave",
                                              "CO2:MATave","ATA:MATave","ACMIA:MATave",
                                              "CMIave:MATave"),2]

PC1_CAC_T$Source<-factor(PC1_CAC_T$Source,levels=rev(c("Intercept","PS","f(SA)","CO2","ATA","ACMIA","CMIave","MATave",
                                                       "f(SA):CO2","f(SA):ATA","f(SA):ACMIA",
                                                       "f(SA):CMIave","f(SA):MATave",
                                                       "CO2:CMIave","ATA:CMIave","ACMIA:CMIave",
                                                       "CO2:MATave","ATA:MATave","ACMIA:MATave",
                                                       "CMIave:MATave")))

## CO2 ##
PC1_CO2_T<-data.table(Source=c("Intercept","PS","f(SA)","CO2","CMIave","MATave",
                               "f(SA):CO2","f(SA):CMIave","f(SA):MATave","CO2:CMIave",
                               "CO2:MATave","CMIave:MATave"),
                      mean.PC1=NA,up.PC1=NA,low.PC1=NA)

PC1_CO2_T$mean.PC1<-summary(m1_CO2_mcmc)$sol[c("(Intercept)","PS","sqrtSA","CO2","CMIave","MATave",
                                               "sqrtSA:CO2","sqrtSA:CMIave","sqrtSA:MATave","CO2:CMIave",
                                               "CO2:MATave","CMIave:MATave"),1]

PC1_CO2_T$up.PC1<-summary(m1_CO2_mcmc)$sol[c("(Intercept)","PS","sqrtSA","CO2","CMIave","MATave",
                                             "sqrtSA:CO2","sqrtSA:CMIave","sqrtSA:MATave","CO2:CMIave",
                                             "CO2:MATave","CMIave:MATave"),3]

PC1_CO2_T$low.PC1<-summary(m1_CO2_mcmc)$sol[c("(Intercept)","PS","sqrtSA","CO2","CMIave","MATave",
                                              "sqrtSA:CO2","sqrtSA:CMIave","sqrtSA:MATave","CO2:CMIave",
                                              "CO2:MATave","CMIave:MATave"),2]

PC1_CO2_T$Source<-factor(PC1_CO2_T$Source,levels=rev(c("Intercept","PS","f(SA)","CO2","CMIave","MATave",
                                                       "f(SA):CO2","f(SA):CMIave","f(SA):MATave","CO2:CMIave",
                                                       "CO2:MATave","CMIave:MATave")))

## ATA ##
PC1_ATA_T<-data.table(Source=c("Intercept","PS","f(SA)","ATA","CMIave","MATave",
                               "f(SA):ATA","f(SA):CMIave","f(SA):MATave","ATA:CMIave",
                               "ATA:MATave","CMIave:MATave"),
                      mean.PC1=NA,up.PC1=NA,low.PC1=NA)

PC1_ATA_T$mean.PC1<-summary(m1_ATA_mcmc)$sol[c("(Intercept)","PS","sqrtSA","ATA","CMIave","MATave",
                                               "sqrtSA:ATA","sqrtSA:CMIave","sqrtSA:MATave","ATA:CMIave",
                                               "ATA:MATave","CMIave:MATave"),1]

PC1_ATA_T$up.PC1<-summary(m1_ATA_mcmc)$sol[c("(Intercept)","PS","sqrtSA","ATA","CMIave","MATave",
                                             "sqrtSA:ATA","sqrtSA:CMIave","sqrtSA:MATave","ATA:CMIave",
                                             "ATA:MATave","CMIave:MATave"),3]

PC1_ATA_T$low.PC1<-summary(m1_ATA_mcmc)$sol[c("(Intercept)","PS","sqrtSA","ATA","CMIave","MATave",
                                              "sqrtSA:ATA","sqrtSA:CMIave","sqrtSA:MATave","ATA:CMIave",
                                              "ATA:MATave","CMIave:MATave"),2]

PC1_ATA_T$Source<-factor(PC1_ATA_T$Source,levels=rev(c("Intercept","PS","f(SA)","ATA","CMIave","MATave",
                                                       "f(SA):ATA","f(SA):CMIave","f(SA):MATave","ATA:CMIave",
                                                       "ATA:MATave","CMIave:MATave")))

## ACMIA ##
PC1_ACMIA_T<-data.table(Source=c("Intercept","PS","f(SA)","ACMIA","CMIave","MATave",
                                 "f(SA):ACMIA","f(SA):CMIave","f(SA):MATave","ACMIA:CMIave",
                                 "ACMIA:MATave","CMIave:MATave"),
                        mean.PC1=NA,up.PC1=NA,low.PC1=NA)

PC1_ACMIA_T$mean.PC1<-summary(m1_ACMIA_mcmc)$sol[c("(Intercept)","PS","sqrtSA","ACMIA","CMIave","MATave",
                                                   "sqrtSA:ACMIA","sqrtSA:CMIave","sqrtSA:MATave","ACMIA:CMIave",
                                                   "ACMIA:MATave","CMIave:MATave"),1]

PC1_ACMIA_T$up.PC1<-summary(m1_ACMIA_mcmc)$sol[c("(Intercept)","PS","sqrtSA","ACMIA","CMIave","MATave",
                                                 "sqrtSA:ACMIA","sqrtSA:CMIave","sqrtSA:MATave","ACMIA:CMIave",
                                                 "ACMIA:MATave","CMIave:MATave"),3]

PC1_ACMIA_T$low.PC1<-summary(m1_ACMIA_mcmc)$sol[c("(Intercept)","PS","sqrtSA","ACMIA","CMIave","MATave",
                                                  "sqrtSA:ACMIA","sqrtSA:CMIave","sqrtSA:MATave","ACMIA:CMIave",
                                                  "ACMIA:MATave","CMIave:MATave"),2]

PC1_ACMIA_T$Source<-factor(PC1_ACMIA_T$Source,levels=rev(c("Intercept","PS","f(SA)","ACMIA","CMIave","MATave",
                                                           "f(SA):ACMIA","f(SA):CMIave","f(SA):MATave","ACMIA:CMIave",
                                                           "ACMIA:MATave","CMIave:MATave")))

#Bind
PC1_CAC_T$model<-"Simultaneous Model"
PC1_CO2_T$model<-"CO2 Individual Model"
PC1_ATA_T$model<-"ATA Individual Model"
PC1_ACMIA_T$model<-"ACMIA Individual Model"

to_gg1<-rbind(PC1_CAC_T,PC1_CO2_T,PC1_ATA_T,PC1_ACMIA_T)
to_gg1$model<-factor(to_gg1$model,levels=c("Simultaneous Model",
                                           "CO2 Individual Model",
                                           "ATA Individual Model",
                                           "ACMIA Individual Model"))

PC1<-ggplot(to_gg1[Source!="Intercept"],aes(x=mean.PC1,xmin=low.PC1,xmax=up.PC1,y=Source,col=model))+
  geom_vline(aes(xintercept=0),linetype="dashed",colour="grey")+ 
  geom_point(position=position_dodge(0.4))+
  geom_errorbar(position=position_dodge(0.4),width=0.2)+
  scale_color_discrete(name="Model")+
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank())+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  xlab(expression(paste("Coefficient estimate")))+ylab("")+
  guides(col=FALSE)
PC1

#### PC2 Graph ####
PC2_CAC_T<-data.table(Source=c("Intercept","PS","f(SA)","CO2","ATA","ACMIA","CMIave","MATave",
                               "f(SA):CO2","f(SA):ATA","f(SA):ACMIA",
                               "f(SA):CMIave","f(SA):MATave",
                               "CO2:CMIave","ATA:CMIave","ACMIA:CMIave",
                               "CO2:MATave","ATA:MATave","ACMIA:MATave",
                               "CMIave:MATave"),
                      mean.PC2=NA,up.PC2=NA,low.PC2=NA)

PC2_CAC_T$mean.PC2<-summary(m2_CAC_mcmc)$sol[c("(Intercept)","PS","sqrtSA","CO2","ATA","ACMIA","CMIave","MATave",
                                               "sqrtSA:CO2","sqrtSA:ATA","sqrtSA:ACMIA",
                                               "sqrtSA:CMIave","sqrtSA:MATave",
                                               "CO2:CMIave","ATA:CMIave","ACMIA:CMIave",
                                               "CO2:MATave","ATA:MATave","ACMIA:MATave",
                                               "CMIave:MATave"),1]

PC2_CAC_T$up.PC2<-summary(m2_CAC_mcmc)$sol[c("(Intercept)","PS","sqrtSA","CO2","ATA","ACMIA","CMIave","MATave",
                                             "sqrtSA:CO2","sqrtSA:ATA","sqrtSA:ACMIA",
                                             "sqrtSA:CMIave","sqrtSA:MATave",
                                             "CO2:CMIave","ATA:CMIave","ACMIA:CMIave",
                                             "CO2:MATave","ATA:MATave","ACMIA:MATave",
                                             "CMIave:MATave"),3]

PC2_CAC_T$low.PC2<-summary(m2_CAC_mcmc)$sol[c("(Intercept)","PS","sqrtSA","CO2","ATA","ACMIA","CMIave","MATave",
                                              "sqrtSA:CO2","sqrtSA:ATA","sqrtSA:ACMIA",
                                              "sqrtSA:CMIave","sqrtSA:MATave",
                                              "CO2:CMIave","ATA:CMIave","ACMIA:CMIave",
                                              "CO2:MATave","ATA:MATave","ACMIA:MATave",
                                              "CMIave:MATave"),2]

PC2_CAC_T$Source<-factor(PC2_CAC_T$Source,levels=rev(c("Intercept","PS","f(SA)","CO2","ATA","ACMIA","CMIave","MATave",
                                                       "f(SA):CO2","f(SA):ATA","f(SA):ACMIA",
                                                       "f(SA):CMIave","f(SA):MATave",
                                                       "CO2:CMIave","ATA:CMIave","ACMIA:CMIave",
                                                       "CO2:MATave","ATA:MATave","ACMIA:MATave",
                                                       "CMIave:MATave")))

## CO2 ##
PC2_CO2_T<-data.table(Source=c("Intercept","PS","f(SA)","CO2","CMIave","MATave",
                               "f(SA):CO2","f(SA):CMIave","f(SA):MATave","CO2:CMIave",
                               "CO2:MATave","CMIave:MATave"),
                      mean.PC2=NA,up.PC2=NA,low.PC2=NA)

PC2_CO2_T$mean.PC2<-summary(m2_CO2_mcmc)$sol[c("(Intercept)","PS","sqrtSA","CO2","CMIave","MATave",
                                               "sqrtSA:CO2","sqrtSA:CMIave","sqrtSA:MATave","CO2:CMIave",
                                               "CO2:MATave","CMIave:MATave"),1]

PC2_CO2_T$up.PC2<-summary(m2_CO2_mcmc)$sol[c("(Intercept)","PS","sqrtSA","CO2","CMIave","MATave",
                                             "sqrtSA:CO2","sqrtSA:CMIave","sqrtSA:MATave","CO2:CMIave",
                                             "CO2:MATave","CMIave:MATave"),3]

PC2_CO2_T$low.PC2<-summary(m2_CO2_mcmc)$sol[c("(Intercept)","PS","sqrtSA","CO2","CMIave","MATave",
                                              "sqrtSA:CO2","sqrtSA:CMIave","sqrtSA:MATave","CO2:CMIave",
                                              "CO2:MATave","CMIave:MATave"),2]

PC2_CO2_T$Source<-factor(PC2_CO2_T$Source,levels=rev(c("Intercept","PS","f(SA)","CO2","CMIave","MATave",
                                                       "f(SA):CO2","f(SA):CMIave","f(SA):MATave","CO2:CMIave",
                                                       "CO2:MATave","CMIave:MATave")))

## ATA ##
PC2_ATA_T<-data.table(Source=c("Intercept","PS","f(SA)","ATA","CMIave","MATave",
                               "f(SA):ATA","f(SA):CMIave","f(SA):MATave","ATA:CMIave",
                               "ATA:MATave","CMIave:MATave"),
                      mean.PC2=NA,up.PC2=NA,low.PC2=NA)

PC2_ATA_T$mean.PC2<-summary(m2_ATA_mcmc)$sol[c("(Intercept)","PS","sqrtSA","ATA","CMIave","MATave",
                                               "sqrtSA:ATA","sqrtSA:CMIave","sqrtSA:MATave","ATA:CMIave",
                                               "ATA:MATave","CMIave:MATave"),1]

PC2_ATA_T$up.PC2<-summary(m2_ATA_mcmc)$sol[c("(Intercept)","PS","sqrtSA","ATA","CMIave","MATave",
                                             "sqrtSA:ATA","sqrtSA:CMIave","sqrtSA:MATave","ATA:CMIave",
                                             "ATA:MATave","CMIave:MATave"),3]

PC2_ATA_T$low.PC2<-summary(m2_ATA_mcmc)$sol[c("(Intercept)","PS","sqrtSA","ATA","CMIave","MATave",
                                              "sqrtSA:ATA","sqrtSA:CMIave","sqrtSA:MATave","ATA:CMIave",
                                              "ATA:MATave","CMIave:MATave"),2]

PC2_ATA_T$Source<-factor(PC2_ATA_T$Source,levels=rev(c("Intercept","PS","f(SA)","ATA","CMIave","MATave",
                                                       "f(SA):ATA","f(SA):CMIave","f(SA):MATave","ATA:CMIave",
                                                       "ATA:MATave","CMIave:MATave")))

## ACMIA ##
PC2_ACMIA_T<-data.table(Source=c("Intercept","PS","f(SA)","ACMIA","CMIave","MATave",
                                 "f(SA):ACMIA","f(SA):CMIave","f(SA):MATave","ACMIA:CMIave",
                                 "ACMIA:MATave","CMIave:MATave"),
                        mean.PC2=NA,up.PC2=NA,low.PC2=NA)

PC2_ACMIA_T$mean.PC2<-summary(m2_ACMIA_mcmc)$sol[c("(Intercept)","PS","sqrtSA","ACMIA","CMIave","MATave",
                                                   "sqrtSA:ACMIA","sqrtSA:CMIave","sqrtSA:MATave","ACMIA:CMIave",
                                                   "ACMIA:MATave","CMIave:MATave"),1]

PC2_ACMIA_T$up.PC2<-summary(m2_ACMIA_mcmc)$sol[c("(Intercept)","PS","sqrtSA","ACMIA","CMIave","MATave",
                                                 "sqrtSA:ACMIA","sqrtSA:CMIave","sqrtSA:MATave","ACMIA:CMIave",
                                                 "ACMIA:MATave","CMIave:MATave"),3]

PC2_ACMIA_T$low.PC2<-summary(m2_ACMIA_mcmc)$sol[c("(Intercept)","PS","sqrtSA","ACMIA","CMIave","MATave",
                                                  "sqrtSA:ACMIA","sqrtSA:CMIave","sqrtSA:MATave","ACMIA:CMIave",
                                                  "ACMIA:MATave","CMIave:MATave"),2]

PC2_ACMIA_T$Source<-factor(PC2_ACMIA_T$Source,levels=rev(c("Intercept","PS","f(SA)","ACMIA","CMIave","MATave",
                                                           "f(SA):ACMIA","f(SA):CMIave","f(SA):MATave","ACMIA:CMIave",
                                                           "ACMIA:MATave","CMIave:MATave")))

#Bind
PC2_CAC_T$model<-"Simultaneous Model"
PC2_CO2_T$model<-"CO2 Individual Model"
PC2_ATA_T$model<-"ATA Individual Model"
PC2_ACMIA_T$model<-"ACMIA Individual Model"

to_gg2<-rbind(PC2_CAC_T,PC2_CO2_T,PC2_ATA_T,PC2_ACMIA_T)
to_gg2$model<-factor(to_gg2$model,levels=c("Simultaneous Model",
                                           "CO2 Individual Model",
                                           "ATA Individual Model",
                                           "ACMIA Individual Model"))

PC2<-ggplot(to_gg2[Source!="Intercept"],aes(x=mean.PC2,xmin=low.PC2,xmax=up.PC2,y=Source,col=model))+
  geom_vline(aes(xintercept=0),linetype="dashed",colour="grey")+ 
  geom_point(position=position_dodge(0.4))+
  geom_errorbar(position=position_dodge(0.4),width=0.2)+
  scale_color_discrete(name="Model")+
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank(),
                    legend.position=c(0.35,0.2),
                    legend.background = element_rect(fill="aliceblue",colour=NA,size=0.2))+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  xlab(expression(paste("Coefficient estimate")))+ylab("")
PC2

#### Bind ####
maxWidth = unit.pmax(PC1$widths[2:3],PC2$widths[2:3])
PC1$widths[2:3] <- maxWidth
PC2$widths[2:3] <- maxWidth

p1<-ggplot_gtable(ggplot_build(PC1))
p2<-ggplot_gtable(ggplot_build(PC2))

tiff("FigSx_MCMCglmm_ClimateEffect_Size.tiff",width=3000,height=2000,res=300,compression="lzw")
grid.draw(cbind(p1,p2,size="last"))
grid.text(expression(paste("a (",CWM[PC1],")")),x=unit(0.19,"npc"),y=unit(0.96,"npc"),gp=gpar(fontsize=12,font=2))
grid.text(expression(paste("b (",CWM[PC2],")")),x=unit(0.69,"npc"),y=unit(0.96,"npc"),gp=gpar(fontsize=12,font=2))

dev.off()

